const fs = require('fs');

const client = process.env.CLIENT;
const interpolationRegex = new RegExp(/%{[A-z]*}/g);

const baseLabels = require(`../labelling-feed/${client}/mock.jc.en`);

function isUnsetLabel(value) {
  return !value && value !== '';
}

function returnInterpolations(label) {
  const matches = label.match(interpolationRegex);
  return matches ? Array.from(new Set(matches)).join(' ') : '';
}

function isLabelPlural(label) {
  return label.includes('||||');
}

function generateLabellingFeed(proposition, countryCode, language) {
  const generatedLabelJSON = readLabelKeysAndValues(proposition, countryCode, language);

  Object.keys(baseLabels).forEach(labelKey => {
    if (isUnsetLabel(generatedLabelJSON[labelKey])) {
      generatedLabelJSON[labelKey] = null;
    }
  });

  Object.keys(generatedLabelJSON).forEach(foreignLabelKey => {
    if (isUnsetLabel(baseLabels[foreignLabelKey])) {
      delete generatedLabelJSON[foreignLabelKey];
    }
  });

  writeLabellingFeed(proposition, countryCode, language, generatedLabelJSON);
}

function generateMockLabellingFeed(proposition, countryCode, language, value) {
  const generatedLabelJSON = readLabelKeysAndValues(proposition, countryCode, language);

  Object.keys(baseLabels).forEach(labelKey => {
    generatedLabelJSON[labelKey] = value;
  });

  Object.keys(generatedLabelJSON).forEach(foreignLabelKey => {
    if (isUnsetLabel(baseLabels[foreignLabelKey])) {
      delete generatedLabelJSON[foreignLabelKey];
    }
  });

  writeLabellingFeed(proposition, countryCode, language, generatedLabelJSON);
}

function readLabelKeysAndValues(proposition, countryCode, language) {
  return require(`../labelling-feed/${client}/${proposition}.${countryCode}.${language}.json`);
}

function writeLabellingFeed(proposition, countryCode, language, generatedLabelJSON) {
  fs.writeFileSync(
    `./labelling-feed/${client}/${proposition}.${countryCode}.${language}.json`,
    `${JSON.stringify(generatedLabelJSON, Object.keys(generatedLabelJSON).sort(), 2)}\n`
  );
}

function generateLabelKeysCSV(proposition, countryCode, language) {
  const labelsJSON = readLabelKeysAndValues(proposition, countryCode, language);

  const csvString = Object.keys(labelsJSON).reduce(
    (acc, key) => `${acc}${key},${returnInterpolations(labelsJSON[key])},${isLabelPlural(labelsJSON[key])}\n`,
    'code,description,plurals\n'
  );

  fs.writeFileSync(`./labelling-feed/${client}/keys.csv`, csvString);
}

if (client === 'web') {
  generateMockLabellingFeed('mock', 'jc', 'jc', 'Cena');
}

// TODO: Remove this when appletv use the label editor, and remove `generateLabellingFeed`
if (client === 'appletv') {
  generateLabellingFeed('nowtv', 'gb', 'en');
  generateLabellingFeed('nowtv', 'de', 'de');
}

generateLabelKeysCSV('mock', 'jc', 'en');
