const hasValidMD5Checksum = require('../utils/has-valid-md5-checksum');

const readOnlyRequestURLS = [
  '/commerce/bridge/charges',
  '/commerce/bridge/voucher/NOWKGET4A6VLNL', // Sports Week Pass - expired
  '/commerce/bridge/voucher/FREENOWTVBOX', // BOX voucher - valid
  '/commerce/bridge/voucher/INVALID_VOUCHER',
  '/commerce/bridge/voucher/MYENTSVOUCHER', // ENTS subscription - valid
  '/commerce/bridge/voucher/MYSPORTSVOUCHER', // Sports subscription - valid
  '/commerce/bridge/voucher/CINEMA_VOUCHER', // CINEMA subscription - valid
  '/commerce/bridge/voucher/PCMS_ERROR',
  '/commerce/bridge/voucher/PENDING',
  '/commerce/bridge/voucher/REDEEMED',
  '/commerce/bridge/voucher/CANCELLED',
  '/commerce/bridge/availableproducts',
];

function securityFailure(ctx) {
  ctx.status = 403;
  ctx.body = {
    errorCode: 'COM_30000',
    description: 'Security failure',
  };
}

function validateRequest(ctx, next) {
  if (ctx.request.get('X-SkyOTT-UserToken') || readOnlyRequestURLS.includes(ctx.path)) {
    if (hasValidMD5Checksum(ctx)) {
      return next();
    } else {
      securityFailure(ctx);
    }
  } else {
    ctx.status = 400;
    ctx.body = {
      errorCode: 'COM_00002',
      description: 'Invalid ott user token provided',
    };
  }
}

function shouldInterceptPath(ctx, pathsToIntercept) {
  if (ctx.request.header['x-sky-signature']) {
    return false;
  }

  const interceptedPaths = pathsToIntercept.filter(path => {
    return ctx.request.url.includes(path);
  });
  return interceptedPaths.length > 0;
}

module.exports = function(pathsToIntercept) {
  return function(ctx, next) {
    if (shouldInterceptPath(ctx, pathsToIntercept)) {
      return validateRequest(ctx, next);
    } else {
      return next();
    }
  };
};
