const fs = require('fs');

const request = require('request-promise-native');
const csv = require('csvtojson');

const pcmsUkUri = 'https://cms.atom.nowtv.com';
const pcmsEuUri = 'https://cms.eu.atom.sky.com';

const ppts = [
  { territory: 'IE', proposition: 'NOWTV', provider: 'NOWTV', language: 'en', baseUri: pcmsUkUri },
  { territory: 'GB', proposition: 'NOWTV', provider: 'NOWTV', language: 'en', baseUri: pcmsUkUri },
  { territory: 'ES', proposition: 'NOWTV', provider: 'NOWTV', language: 'es', baseUri: pcmsEuUri },
  { territory: 'DE', proposition: 'NOWTV', provider: 'NOWTV', language: 'de', baseUri: pcmsEuUri },
  { territory: 'IT', proposition: 'NOWTV', provider: 'NOWTV', language: 'it', baseUri: pcmsEuUri },
];

async function callPcmsMissingLabels({ proposition, provider, territory, language, baseUri }) {
  const response = await request({
    uri: `${baseUri}/core/label/keys_missing_values/COMPUTER:PC/${language}`,
    method: 'GET',
    headers: {
      'X-SkyOTT-Proposition': proposition,
      'X-SkyOTT-Provider': provider,
      'X-SkyOTT-Territory': territory,
      'X-SkyOTT-Service': process.env.CMS_USERNAME,
      'X-SkyOTT-ServiceToken': process.env.CMS_PASSWORD,
    },
  });

  return response;
}

async function getMissingLabels() {
  const labelKeys = await csv({ ignoreEmpty: true, flatKeys: true })
    .fromFile(`${__dirname}/../labelling-feed/web/keys.csv`)
    .then(data => data.map(line => line.code));

  await Promise.all(
    ppts.map(async ppt => {
      const response = await callPcmsMissingLabels(ppt);
      const missingLabels = await csv({ ignoreEmpty: true, flatKeys: true })
        .fromString(response)
        .then(data => data.map(line => line.code));

      const labelsTxt = missingLabels.filter(label => labelKeys.includes(label)).join('\n');
      fs.writeFileSync(`${__dirname}/${ppt.proposition}-${ppt.territory}.txt`, labelsTxt);
    })
  );
}

getMissingLabels();
