/* eslint-env browser */

// This mock supports the override variations feature from the Optimizely API
// https://developers.optimizely.com/x/solutions/javascript/topics/query-parameters/index.html

// Add experiments to mock out here

const experiments = [
  {
    name: 'shop',
    id: 'e001',
    variations: [
      {
        name: 'v1',
        id: 'v001',
      },
      {
        name: 'v2',
        id: 'v002',
      },
    ],
  },
  {
    name: 'shop-other',
    id: 'e002',
    variations: [
      {
        name: 'v1',
        id: 'v003',
      },
      {
        name: 'v2',
        id: 'v004',
      },
    ],
  },
];

// Should be no need to modify the code below unless you want to expose additional functionality of the Optimizely API
const experimentStates = {};
const searchParams = new URLSearchParams(location.search);
const optimizelyX = searchParams.getAll('optimizely_x');

experiments.forEach(({ name: experimentName, id: experimentId, variations }) => {
  const matchedVariation = variations.find(({ name: variationName, id: variationId }) => {
    return optimizelyX.includes(`${experimentName}|${variationName}`) || optimizelyX.includes(`${variationId}`);
  });
  if (matchedVariation) {
    addExperimentVariation({
      experimentName,
      experimentId,
      variationId: matchedVariation.id,
      variationName: matchedVariation.name,
    });
  }
});

function addExperimentVariation({ experimentName, experimentId, variationName, variationId }) {
  experimentStates[experimentId] = {
    experimentName,
    id: experimentId,
    isActive: true,
    variation: {
      id: variationId,
      name: variationName,
    },
  };
}

window.optimizely = {
  push() {},
  get(arg) {
    if (arg === 'state') {
      return {
        getExperimentStates() {
          return experimentStates;
        },
      };
    }
  },
};
