const { isScenario } = require('../../utils/scenario');

const accountNotFound = require('./bt/associate-device/account-not-found');
const accountInvalid = require('./bt/associate-device/account-invalid');
const deviceNotAvailable = require('./bt/associate-device/device-not-available');
const suitableEntitlementsNotFound = require('./bt/associate-device/suitable-entitlements-not-found');
const drmInformationNotAvailable = require('./bt/associate-device/drm-information-not-available');
const internalServiceException = require('./bt/associate-device/internal-service-exception');
const minimumRequiredSoftwareVersion = require('./bt/associate-device/minimum-required-software-version');
const minimumRequiredSoftwareVersionOnDemand = require('./bt/associate-device/minimum-required-software-version-on-demand');
const minimumRequiredSoftwareVersionLinear = require('./bt/associate-device/minimum-required-software-version-linear');
const minimumRequiredSoftwareVersionHelperApp = require('./bt/associate-device/minimum-required-software-version-helper-app');
const deviceModelBlocked = require('./bt/associate-device/device-model-blocked');
const deviceLimitReached = require('./bt/associate-device/device-limit-reached');
const accountSuspended = require('./bt/associate-device/account-suspended');
const success = require('./bt/associate-device/success');
const successEligible = require('./bt/associate-device/success-eligible');

const errorResponseMap = {
  bt_account_invalid: accountInvalid,
  bt_account_not_found: accountNotFound,
  bt_device_not_available: deviceNotAvailable,
  bt_drm_information_not_available: drmInformationNotAvailable,
  bt_suitable_entitlements_not_found: suitableEntitlementsNotFound,
  bt_internal_service_exception: internalServiceException,
  bt_minimum_required_software_version_on_demand: minimumRequiredSoftwareVersionOnDemand,
  bt_minimum_required_software_version_linear: minimumRequiredSoftwareVersionLinear,
  bt_minimum_required_software_version_helper_app: minimumRequiredSoftwareVersionHelperApp,
  bt_minimum_required_software_version: minimumRequiredSoftwareVersion,
  bt_device_model_blocked: deviceModelBlocked,
  bt_device_limit_reached: deviceLimitReached,
  bt_account_suspended: accountSuspended,
  bt_success_eligible: successEligible,
  bt_success: success,
};

module.exports = function(ctx) {
  const matchingErrorKey = Object.keys(errorResponseMap).find(errorKey => isScenario(ctx, errorKey));
  const responseBody = matchingErrorKey ? errorResponseMap[matchingErrorKey] : internalServiceException;
  return (ctx.body = responseBody);
};
