const _ = require('lodash');

const { isScenario } = require('../../utils/scenario');

const productsFixture = require('./commerce/products/products');
const { getSubscriptionsForUser } = require('./subscriptions');
const { getEntitlementsForUser } = require('./entitlements');

function filterAvailableProducts(products, id) {
  const product = products.find(p => p.static_id === id);
  if (product) {
    product.available = false;
    products.filter(p => p.category === product.category).forEach(p => (p.available = false));
  }
}

function getProductsForUser(userToken, subscriptions, entitlements = []) {
  if (userToken.includes('user_with_trials_used') || userToken.includes('user_with_credit_and_trials_used')) {
    return require('./commerce/products/trials-used');
  }
  if (userToken.includes('user_with_multipass_trial')) {
    return require('./commerce/products/multipass-trials');
  }
  const products = _.cloneDeep(productsFixture);
  subscriptions.forEach(subscription => filterAvailableProducts(products, subscription.product.staticId));
  entitlements.forEach(entitlement => filterAvailableProducts(products, entitlement.productStaticId));

  if (subscriptions.length === 0 && entitlements.length === 0) {
    products.find(product => product.category === 'HD').available = false;
  }

  return products;
}

module.exports = {
  post(ctx) {
    if (isScenario(ctx, 'get_available_products_server_error')) {
      return (ctx.status = 500);
    }

    let currentEntitlements;
    let currentSubscriptions;
    let products;

    if (!ctx.request.get('X-SkyOTT-UserToken')) {
      // signed Out user requesting available products
      currentEntitlements = [];
      currentSubscriptions = [];
      products = productsFixture;
    } else {
      currentEntitlements = getEntitlementsForUser(ctx).entitlements || [];
      currentSubscriptions = getSubscriptionsForUser(ctx).subscriptions || [];
      products = getProductsForUser(ctx.request.get('X-SkyOTT-UserToken'), currentSubscriptions, currentEntitlements);
      if (isScenario(ctx, 'no_entertainment_available_products')) {
        products = products.filter(product => product.category !== 'ENTERTAINMENT');
      }
      ctx.set('X-SkyOTT-UserToken', ctx.request.get('X-SkyOTT-UserToken'));
    }

    ctx.status = 200;
    ctx.type = 'application/vnd.getproducts.v1+json';
    ctx.body = {
      currentEntitlements,
      currentSubscriptions,
      catalogue: {
        currency: 'EUR',
        offers: [],
        products,
      },
      warnings: [],
    };
  },
};
