const userIdentifier = require('../../utils/user-identifier');

function getEntitlementsForUser(ctx) {
  const user = userIdentifier.getDataForUserOrDefault(ctx);

  const purchasedProductIds = ctx.persistentStore.get('purchased');
  if (purchasedProductIds) {
    const userEntitlements = user.entitlements || [];
    const entitlements = purchasedProductIds.reduce((acc, id) => {
      try {
        const entitlementData = require(`./commerce/entitlements/${id}.json`);
        if (entitlementData) {
          return acc.concat(entitlementData);
        }
        return acc;
      } catch (e) {
        return acc;
      }
    }, []);

    return {
      entitlements: userEntitlements.concat(entitlements),
    };
  }

  return {
    entitlements: user.entitlements,
  };
}

module.exports.getEntitlementsForUser = getEntitlementsForUser;

module.exports.get = function(ctx) {
  const data = getEntitlementsForUser(ctx);

  ctx.status = 200;
  ctx.set('X-SkyOTT-UserToken', ctx.request.get('X-SkyOTT-UserToken'));
  ctx.body = data;
  ctx.type = 'application/vnd.entitlements.v1+json';
};
