const get = require('lodash/get');

const { isScenario } = require('../../utils/scenario');
const userIdentifier = require('../../utils/user-identifier');
const users = require('../sky-id/sky-id/users');

module.exports.get = function(ctx) {
  const userToken = ctx.request.get('X-SkyOTT-UserToken');
  const user = users[userToken] || {};
  let paymentAccounts = userIdentifier.getDataItemForUserOrDefault(ctx, 'paymentAccounts');

  if (user.noPaymentAccount || isScenario(ctx, 'commerce_no_payment_account')) {
    paymentAccounts = users.user_with_no_card_details.paymentAccounts;
  }

  const { changeToCard, changeToPaypal } = ctx.persistentStore.get('paymentAccount') || {};

  if (changeToCard) {
    paymentAccounts = users.valid_user.paymentAccounts;
  }

  if (changeToPaypal) {
    paymentAccounts = users.user_with_paypal_details.paymentAccounts;
  }

  ctx.set('X-SkyOTT-UserToken', userToken);
  if (isScenario(ctx, 'payment_account_service_down')) {
    ctx.status = 500;
  } else {
    ctx.status = paymentAccounts.paymentAccounts ? 200 : 404;
    ctx.body = paymentAccounts;
    ctx.set('Content-Type', 'application/vnd.paymentaccounts.v1+json');
  }
};

module.exports.postSingle = function(ctx) {
  const newPaymentMethodType = get(ctx, ['request', 'body', 'paymentAccount', 'paymentMethodType'], '');

  if (newPaymentMethodType === 'CARD') {
    ctx.persistentStore.set('paymentAccount', { changeToCard: true });
  }

  if (newPaymentMethodType === 'PAYPAL') {
    ctx.persistentStore.set('paymentAccount', { changeToPaypal: true });
  }

  if (isScenario(ctx, 'store_payment_account_error')) {
    ctx.status = 500;
  } else {
    const userToken = ctx.request.get('X-SkyOTT-UserToken');
    ctx.status = 204;
    ctx.set('X-SkyOTT-UserToken', userToken);
  }
};

module.exports.resetFixtures = function(ctx) {
  ctx.persistentStore.delete('paymentAccount');
  ctx.body = `Fixtures for payment account have been reset for user: ${ctx.request.query.userToken}`;
  ctx.status = 200;
};
