const _ = require('lodash');

const { isScenario } = require('../../utils/scenario');
const userIdentifier = require('../../utils/user-identifier');

const priceBasketData = require('./commerce/sales/price-basket/success');
const priceBasketOfferData = require('./commerce/sales/price-basket/offer');
const priceBasketOfferDataButPCMSDown = require('./commerce/sales/price-basket/offer-pcms-down');
const purchaseBasketDeliveryAddressMissing = require('./commerce/sales/purchase-basket/missing-delivery-address.json');

function includesVoucher(vouchers, voucherCode) {
  return vouchers && vouchers.includes && vouchers.includes(voucherCode);
}

function addChargeTotalsToResponse(response, discount) {
  response.charge_totals.recurring.point_of_sale_amount = (
    Math.round(response.charge_totals.recurring.full_amount * (100 - discount)) / 100
  ).toString();
  response.charge_totals.total.point_of_sale_amount = (
    Math.round(response.charge_totals.total.full_amount * (100 - discount)) / 100
  ).toString();
  response.charge_totals.non_recurring.point_of_sale_amount = (
    Math.round(response.charge_totals.non_recurring.full_amount * (100 - discount)) / 100
  ).toString();
}

function addBasketSummaryToContext(ctx, user) {
  if (ctx.persistentStore.get('creditBalancePrePurchase') || user.creditBalancePrePurchase) {
    ctx.body.basket_payment_summary = {
      credit_amount: '11.99',
      credit_balance_post_purchase: '38.01',
      credit_balance_pre_purchase: ctx.persistentStore.get('creditBalancePrePurchase') || user.creditBalancePrePurchase,
      payment_account_amount: '0.00',
    };
  }
}

function calculateAmount(acc, cloned) {
  return parseFloat(parseFloat(acc) + parseFloat(cloned)).toFixed(2);
}

module.exports.priceBasket = ctx => {
  const user = userIdentifier.getDataForUserOrDefault(ctx);

  if (ctx.request.body) {
    if (ctx.request.body.vouchers && ctx.request.body.vouchers.length > 0) {
      if (
        includesVoucher(ctx.request.body.vouchers, 'MYENTSVOUCHER') ||
        includesVoucher(ctx.request.body.vouchers, 'MYSPORTSVOUCHER') ||
        includesVoucher(ctx.request.body.vouchers, 'VALID_THEN_VALID_THEN_INVALID_VOUCHER_CODE')
      ) {
        const businessId = includesVoucher(ctx.request.body.vouchers, 'MYENTSVOUCHER') ? 'C_002009' : 'C_002013';
        const response = _.cloneDeep(priceBasketData[businessId] || priceBasketData.default);
        response.selection.offers.push(priceBasketOfferData);
        const discount = priceBasketOfferData.discounts[0].value;
        addChargeTotalsToResponse(response, discount);
        ctx.body = response;
        addBasketSummaryToContext(ctx, user);
        return;
      } else if (includesVoucher(ctx.request.body.vouchers, 'FREENOWTVBOX')) {
        const businessId = 'C_002020';
        const response = _.cloneDeep(priceBasketData[businessId] || priceBasketData.default);
        response.selection.offers.push(priceBasketOfferData);
        const discount = priceBasketOfferData.discounts[0].value;
        addChargeTotalsToResponse(response, discount);
        ctx.body = response;
        addBasketSummaryToContext(ctx, user);
        return;
      } else if (includesVoucher(ctx.request.body.vouchers, 'PCMS_ERROR')) {
        const businessId = 'C_002013';
        const response = _.cloneDeep(priceBasketData[businessId] || priceBasketData.default);
        response.selection.offers.push(priceBasketOfferDataButPCMSDown);
        const discount = priceBasketOfferDataButPCMSDown.discounts[0].value;
        addChargeTotalsToResponse(response, discount);
        ctx.body = response;
        addBasketSummaryToContext(ctx, user);
        return;
      } else if (includesVoucher(ctx.request.body.vouchers, 'CINEMA_VOUCHER')) {
        const businessId = 'C_002002';
        const response = _.cloneDeep(priceBasketData[businessId] || priceBasketData.default);
        response.selection.offers.push({
          business_id: 'OF_002869',
          classification: 'Covert',
          discounts: [
            {
              business_id: 'D_002870',
              duration: 'P2M',
              name: 'A Valid Offer For 2 Months',
              static_id: '2_MONTHS_10_OFF_MOVIES_MONTH_PASS',
              type: 'Percentage',
              value: '10',
            },
          ],
          name: 'Some legit offer that is really good',
          static_id: '2_MONTHS_10_OFF_MOVIES_MONTH_PASS',
        });

        const discount = priceBasketOfferData.discounts[0].value;
        addChargeTotalsToResponse(response, discount);
        ctx.body = response;
        addBasketSummaryToContext(ctx, user);
        return;
      } else if (
        includesVoucher(ctx.request.body.vouchers, 'VALID_THEN_INVALID_VOUCHER_CODE') ||
        includesVoucher(ctx.request.body.vouchers, 'INVALID_VOUCHER')
      ) {
        ctx.status = 400;
        ctx.body = require('./commerce/sales/price-basket/voucher-error');
        return;
      } else if (
        includesVoucher(ctx.request.body.vouchers, 'NOT_ELIGIBLE_FOR_OFFER') &&
        ctx.request.get('X-SkyOTT-UserToken')
      ) {
        ctx.status = 400;
        ctx.body = require('./commerce/sales/price-basket/not-eligible-for-offer-error');
        return;
      } else if (includesVoucher(ctx.request.body.vouchers, 'MULTI_PROMO') && ctx.request.get('X-SkyOTT-UserToken')) {
        ctx.status = 400;
        ctx.body = require('./commerce/sales/price-basket/multi-promo-price-basket');
        return;
      }
    } else if (ctx.request.body.products) {
      ctx.body = ctx.request.body.products.reduce(
        (acc, product) => {
          const cloned = _.cloneDeep(priceBasketData[product.id] || priceBasketData.default);
          if (!acc.selection) {
            return { ...acc, ...cloned };
          }
          return {
            ...acc,
            charge_totals: {
              total: {
                ...acc.charge_totals.total,
                point_of_sale_amount: calculateAmount(
                  acc.charge_totals.total.point_of_sale_amount,
                  cloned.charge_totals.total.point_of_sale_amount
                ),
                full_amount: calculateAmount(
                  acc.charge_totals.total.full_amount,
                  cloned.charge_totals.total.full_amount
                ),
                next_renewal_amount: calculateAmount(
                  acc.charge_totals.total.next_renewal_amount,
                  cloned.charge_totals.total.next_renewal_amount
                ),
              },
            },
            selection: {
              products: [...acc.selection.products, ...cloned.selection.products],
            },
            charges: [...acc.charges, ...cloned.charges],
          };
        },
        {
          charge_totals: {
            total: {
              point_of_sale_amount: '0.00',
              next_renewal_amount: '0.00',
              total_amount: '0.00',
            },
          },
        }
      );

      if (isScenario(ctx, 'price_increase')) {
        ctx.body.charges[0] = {
          ...ctx.body.charges[0],
          future_price: '99999',
          future_price_effective_date: '2048-03-21T01:00:00.000Z',
        };
      }

      if (isScenario(ctx, 'purchase_eligible_for_upgrade')) {
        if (ctx.request.body.products.length < 2) {
          ctx.body.advice = [
            {
              advice_code: 'DOGS_ADV_901',
              advice_message: 'Entertainment Month Pass (C_003084) makes customer eligible to purchase C_006602.',
              reference_ids: ['C_006602'],
              reference_static_ids: ['HD_SUBSCRIPTION_MONTH'],
              subject_ids: ['C_003084'],
              subject_static_ids: ['ENTERTAINMENT_SUBSCRIPTION_MONTH'],
            },
            {
              advice_code: 'DOGS_ADV_901',
              advice_message: 'Entertainment Month Pass (C_003084) makes customer eligible to purchase C_006602.',
              reference_ids: ['C_006935'],
              reference_static_ids: ['FT_HD'],
              subject_ids: ['C_003084'],
              subject_static_ids: ['ENTERTAINMENT_SUBSCRIPTION_MONTH'],
            },
          ];
        }
      }

      addBasketSummaryToContext(ctx, user);

      return;
    }
  }

  ctx.status = 400;
  ctx.body = require('./commerce/sales/price-basket/error');
};

module.exports.purchaseBasket = ctx => {
  const user = userIdentifier.getDataForUserOrDefault(ctx);
  if (isScenario(ctx, 'geo_block_error')) {
    ctx.status = 403;
    ctx.body = require('./commerce/sales/purchase-basket/geo_block_error');
  } else if (ctx.request.body && ctx.request.body.payment.paymentPin === '9999') {
    ctx.status = 400;
    ctx.body = require('./commerce/sales/purchase-basket/invalid-pin');
  } else if (
    ctx.request.body &&
    Array.isArray(ctx.request.body.vouchers) &&
    includesVoucher(ctx.request.body.vouchers, 'VALID_THEN_VALID_THEN_INVALID_VOUCHER_CODE')
  ) {
    ctx.status = 400;
    ctx.body = require('./commerce/sales/purchase-basket/voucher-error');
  } else if (ctx.request.body && user.hasUsedTrials) {
    ctx.status = 400;
    ctx.body = { errorCode: 'COM_00015', description: 'Only one trial per payment card is allowed' };
  } else if (isScenario(ctx, 'credit_not_available')) {
    ctx.status = 400;
    ctx.body = { errorCode: 'COM_00028', description: 'The credit amount authorised was not available to be redeemed' };
  } else if (isScenario(ctx, 'generic_payment_error')) {
    ctx.status = 400;
    ctx.body = require('./commerce/sales/purchase-basket/payment-error');
  } else if (ctx.request.body && user.genericPaymentError !== true) {
    if (ctx.request.body.products) {
      const products = ctx.request.body.products;
      const productsRequiringAddress = ['C_003130'];
      const productsSettingAccountSegments = { C_006602: { name: 'HD' } };

      const accountSegmentProduct = products.find(product =>
        Object.keys(productsSettingAccountSegments).includes(product.id)
      );

      if (accountSegmentProduct) {
        ctx.persistentStore.set('purchasedAccountSegments', [
          ...(ctx.persistentStore.get('purchasedAccountSegments') || []),
          productsSettingAccountSegments[accountSegmentProduct.id],
        ]);
      }

      if (products.some(product => productsRequiringAddress.includes(product.id)) && !ctx.request.body.delivery) {
        ctx.status = 400;
        ctx.body = purchaseBasketDeliveryAddressMissing;
        return;
      }

      const ids = products.map(product => {
        const productId = product.id;
        const trialToProductMapping = {
          C_003088: 'C_002002',
          C_003084: 'C_002009',
          C_003120: 'C_003116',
        }[productId];

        return trialToProductMapping || productId;
      });

      const authResult = _.get(ctx.request.body, ['payment', 'paymentProtectionResult', '3DSecureAuthorisationResult']);
      if (isScenario(ctx, '3d_secure') && !authResult) {
        ctx.body = require('./commerce/sales/purchase-basket/3d-secure-required.json');
        return;
      }

      ctx.body = require('./commerce/sales/purchase-basket/success');
      ctx.persistentStore.set('purchased', [...(ctx.persistentStore.get('purchased') || []), ...ids]);
    } else if (ctx.request.body.vouchers) {
      const voucherCodeToProductMapping = {
        CINEMA_VOUCHER: 'C_002002',
        MYENTSVOUCHER: 'C_002009',
        FREENOWTVBOX: 'C_002020',
      };

      ctx.persistentStore.set('purchased', [voucherCodeToProductMapping[ctx.request.body.vouchers[0]]]);
      ctx.body = require('./commerce/sales/purchase-basket/success');
    }
  } else {
    ctx.status = 400;
    ctx.body = require('./commerce/sales/purchase-basket/payment-error');
  }

  ctx.type = 'application/vnd.purchase.v1+json';
};

module.exports.resetFixtures = ctx => {
  ctx.persistentStore.delete('purchased');
  ctx.persistentStore.delete('cancelled');
  ctx.persistentStore.delete('purchasedAccountSegments');
  ctx.persistentStore.delete('playoutPass');

  ctx.body = `Fixtures for purchase and cancellation have been reset for user: ${ctx.request.query.userToken}`;
  ctx.status = 200;
};
