const userIdentifier = require('../../utils/user-identifier');

function getSubscriptionsForUser(ctx) {
  const user = userIdentifier.getDataForUserOrDefault(ctx);

  const cancelledId = ctx.persistentStore.get('cancelled');
  const fourDaysFromNow = new Date(Date.now() + 1000 * 60 * 60 * 24 * 4).toISOString();

  const purchasedProductId = ctx.persistentStore.get('purchased');
  if (purchasedProductId) {
    try {
      const productData = require(`./commerce/subscriptions/${purchasedProductId}.json`);
      if (productData) {
        return {
          subscriptions: user.subscriptions.concat(productData),
        };
      }
    } catch (e) {
      // no worries, probably just a pass
    }
  }

  return {
    subscriptions: (user.subscriptions || []).map(subscription => {
      if (subscription.cancellationEffectiveDate) {
        return Object.assign({}, subscription, {
          cancellationEffectiveDate: fourDaysFromNow,
        });
      }

      if (cancelledId && subscription.id === cancelledId) {
        return Object.assign({}, subscription, {
          state: 'USER_CANCELLED',
          allowedOperations: ['REINSTATE', 'DELETE'],
          cancellationEffectiveDate: fourDaysFromNow,
        });
      }

      return subscription;
    }),
  };
}

module.exports.getSubscriptionsForUser = getSubscriptionsForUser;

module.exports.get = function(ctx) {
  const data = getSubscriptionsForUser(ctx);

  ctx.status = 200;
  ctx.set('X-SkyOTT-UserToken', ctx.request.get('X-SkyOTT-UserToken'));
  ctx.body = data;
  ctx.type = 'application/vnd.latestsubscriptions.v1+json';
};
