const { isScenario } = require('../../utils/scenario');

const nowNextFixture = require('./epg/now-next/now-next-channels');

const isOneOfScenarios = (ctx, scenarios) => scenarios.some(scenario => isScenario(ctx, scenario));

const generateEpochTimeFromNow = (secondsFromNow = 0) => +`${Date.now() - secondsFromNow * 1000}`.slice(0, -3);

const setStartTimeEpochFromNow = (item, secondsUntilSwitch = 0) => ({
  ...item,
  now: {
    ...item.now,
    startTimeEpoch: generateEpochTimeFromNow(item.now.durationInSeconds - secondsUntilSwitch),
  },
  next: {
    ...item.next,
    startTimeEpoch: generateEpochTimeFromNow(item.now.durationInSeconds),
  },
});

const switchNowWithNext = item => ({
  ...item,
  now: {
    ...item.next,
  },
  next: {
    ...item.now,
  },
});

const outdatedSchedule = requestedChannels => requestedChannels.map(item => setStartTimeEpochFromNow(item, -100));
const switchedSchedule = requestedChannels =>
  requestedChannels.map(switchNowWithNext).map(item => setStartTimeEpochFromNow(item, item.now.durationInSeconds));
const scheduleSwitchingSoon = requestedChannels => requestedChannels.map(item => setStartTimeEpochFromNow(item, 5));

const findRequestedChannels = ctx => {
  const { nowNext } = nowNextFixture;
  const requestedServiceKeys = ctx.params.keys.split(',');
  return requestedServiceKeys.map(serviceKey => nowNext.find(item => item.serviceKey === serviceKey)).filter(x => x);
};

const isRequestedDuringPlayback = ctx => (ctx.request.get('Referer') || '').includes('/playback/live/');

const setNowNextResponse = (ctx, channels) => {
  ctx.body = {
    nowNext: channels,
  };
};

const PROGRAMME_CHANGE_SCENARIO = 'parental_pin_on_programme_change';
const OUTDATED_SCHEDULE_SCENARIO = 'parental_pin_on_outdated_schedule';

module.exports.get = function(ctx) {
  const channels = findRequestedChannels(ctx);

  if (!isOneOfScenarios(ctx, [PROGRAMME_CHANGE_SCENARIO, OUTDATED_SCHEDULE_SCENARIO])) {
    return setNowNextResponse(ctx, channels);
  }

  if (!isRequestedDuringPlayback(ctx)) {
    return setNowNextResponse(
      ctx,
      isScenario(ctx, OUTDATED_SCHEDULE_SCENARIO) ? outdatedSchedule(channels) : scheduleSwitchingSoon(channels)
    );
  }

  return setNowNextResponse(ctx, switchedSchedule(channels));
};
