require('./import-query');

const fs = require('fs');
const path = require('path');

const request = require('request-promise-native');
const kidsGroupQuery = require('atlas-tv-redux/src/queries/kids-group.graphql');
const catalogueQuery = require('atlas-tv-redux/src/queries/catalogue.graphql');

const addTypenames = file =>
  file.replace(/\{\n(\s+)\.\.\. on /g, (match, spaces) => match.replace('...', `__typename\n${spaces}...`));

const revertAliases = file => file.replace(/(\w+): (\w+\(.+\))/g, (match, alias, name) => name);

const parsedKidsGroupQuery = revertAliases(addTypenames(kidsGroupQuery));
const parsedCatalogueQuery = revertAliases(addTypenames(catalogueQuery));

const getIds = dir =>
  fs
    .readdirSync(path.join(__dirname, dir))
    .filter(name => name.match('.json'))
    .map(name => name.replace('.json', ''));

const collections = getIds('./collections');
const groups = getIds('./groups');

const saveToJson = (filePath, data) => fs.writeFileSync(filePath, `${JSON.stringify(data, null, 2)}\n`);

const buildFilePath = (directory, id) => path.join(__dirname, `./${directory}/${id}.json`);

const saveKidsGroup = (id, data) =>
  saveToJson(buildFilePath('groups', id), (data && data.data && data.data.group) || data);

const saveCatalogue = (id, data) =>
  saveToJson(buildFilePath('collections', id), (data && data.data && data.data.catalogue) || data);

async function fetchMock(query, variables) {
  const data = await request.post({
    uri: process.env.GRAPHQL_SERVER,
    body: JSON.stringify({
      query,
      variables,
    }),
    headers: {
      'Content-Type': 'application/json',
      'X-SkyOTT-Territory': 'jc',
    },
  });

  return JSON.parse(data);
}

Promise.all([
  ...groups.map(async id => {
    const data = await fetchMock(parsedKidsGroupQuery, { id });
    saveKidsGroup(id, data);
  }),
  ...collections.map(async id => {
    const data = await fetchMock(parsedCatalogueQuery, { id, limit: 100 });
    saveCatalogue(id, data);
  }),
]).catch(err => {
  console.error(err.message); // eslint-disable-line no-console
});
