const http = require('http');
const path = require('path');
const fs = require('fs');

const Router = require('koa-router');
const cookie = require('koa-cookie');
const proxy = require('koa-proxies');

// Routes
// - Adobe Analytics
const adobeAnalytics = require('./adobe-analytics/adobe-analytics');
// - Bookmarks
const bookmarks = require('./bookmarks/bookmarks');
// - BT
const associateDevice = require('./bt/associate-device');
const partnersService = require('./bt/partners-service');
// - Commerce
const accountManager = require('./commerce/account-manager');
const activate = require('./commerce/activate');
const availableProducts = require('./commerce/available-products');
const cancelRenewal = require('./commerce/cancel-renewal');
const entitlements = require('./commerce/entitlements');
const pvsEtitlements = require('./commerce/pvs-entitlements');
const orderHistory = require('./commerce/order-history');
const paymentAccounts = require('./commerce/payment-accounts');
const paymentPin = require('./commerce/payment-pin');
const reinstateSubscription = require('./commerce/reinstate-subscription');
const sales = require('./commerce/sales');
const subscriptions = require('./commerce/subscriptions');
const vouchers = require('./commerce/vouchers');
const creditManager = require('./commerce/credit-manager');
// - Config
const config = require('./config/config');
// - EPG
const nowNext = require('./epg/now-next');
// - My TV
const mytvWatchlist = require('./my-tv/watchlist');
const continueWatching = require('./my-tv/continue-watching');
const personalisedRecsMovies = require('./pcms/personalised-recs-movies');
const personalisedRecsEntertainment = require('./pcms/personalised-recs-entertainment');
const personalisedRecsMixed = require('./pcms/personalised-recs-mixed');
const recentlyViewed = require('./my-tv/recently-viewed');
// - Oogway
const oogwayProfile = require('./oogway/profile');
// - PCMS
const { getAtomMockForTerritory } = require('./pcms/get-atom-mock');
const labellingFeed = require('./pcms/labelling-feed');
const linearChannels = require('./pcms/linear-channels');
const menu = require('./pcms/menu');
const ottCertificate = require('./pcms/ott-certificate');
const audioSubtitle = require('./pcms/audio-subtitle');
const promoPage = require('./pcms/promo-pages');
const promotions = require('./pcms/promotions');
const queryStaticId = require('./pcms/query-static-id');
const sportsFixtures = require('./pcms/sports-fixtures');
const supportedLanguages = require('./pcms/supported-languages');
// - PCMS Widgets
const widgets = require('./pcms/widgets');
const legalBit = require('./pcms/widgets/legal-bit');
const privacy = require('./pcms/widgets/privacy');
const terms = require('./pcms/widgets/terms');
// - Playout
const playoutsLive = require('./playouts/live');
const playoutsVOD = require('./playouts/vod');
const playPreview = require('./playouts/play-preview');
// - Prime
const prime = require('./prime/prime');
// - Search
const searchSuggest = require('./search/search-suggest');
// - Entity search
const entitySearch = require('./entity-search/entity-search');
// - Sky ID
const skyid = require('./sky-id/sky-id');
// - External My Account
const externalMyAccount = require('./external/my-account');
// - UMV
const userToken = require('./umv/user-token');
//   ~ 3D Secure
const threeDSecure = require('./3d-secure');
// - Persona Store
const personaStore = require('./persona-store');
// - Time service
const timeService = require('./time-service');
// - Lightstreamer
const lightstreamer = require('./lightstreamer/lightstreamer');
// - GraphQl 🚀
const graphQl = require('./graphql');
const credit = require('./credit/credit');
// - MVPD Gateway Service
const mgs = require('./mgs');
// - Partner Account Manager
const pam = require('./pam');
// - Adobe Primetime Service
const adobePrimetimeService = require('./adobe-primetime-service');

module.exports = function(app) {
  const router = new Router();
  router.use(cookie.default());

  // Prime
  router.get('/prime', prime.view);
  router.post('/prime/user', prime.createUser);

  // Credit
  router.get('/credit/add', credit.addCredit);

  // Adobe Analytics
  router.get('/adobe-analytics/reset', adobeAnalytics.reset);
  router.get('/adobe-analytics/tracked-requests', adobeAnalytics.trackedRequests);
  router.get('/adobe-analytics*', adobeAnalytics.trackGet);
  router.post('/adobe-analytics*', adobeAnalytics.trackPost);

  // BT
  router.post('/ngda/nowtv/V2.0/associateDevice/', associateDevice);
  router.get('/pas/V1/partnerAccountInfo/NowTv/:deviceId?', partnersService);

  // GraphQL
  router.post('/graphql', graphQl);

  // UMV
  router.post('/auth/tokens', userToken.getUserToken);
  router.get('/auth/users/me', userToken.getUserDetails);
  router.get('/auth/users/me/parental-control', userToken.getUserParentalControl);

  // Sky ID - Sign In
  router.get('/signin/service/*', skyid.getSigninForm);
  router.post('/signin/service/*', skyid.signin);
  router.post('/signin/securitycheck/service/*', skyid.signInCaptcha);
  router.post('/signin/captcha', skyid.signInCaptchaData);
  router.get('/signin/captcha/:type/:id', skyid.captchaAssets);

  // Sky ID - Get Profile
  router.get('/modifyprofile/display/service/*', skyid.getProfile);
  router.get('/modifyprofile/service/*', skyid.getModifyUserProfile);
  router.post('/modifyprofile/service/*', skyid.postModifyUserProfile);
  router.post('/modifyprofile/activationstatus/service/*', skyid.postActivationStatus);
  router.get('/reset-fixtures/sky-id', skyid.resetFixtures);

  // Sky ID - Sign Up
  router.get('/signup/service/*', skyid.getSignupForm);
  router.post('/signup/service/*', skyid.createProfile);
  router.post('/signup/captcha', skyid.signupCaptcha);
  router.get('/signup/captcha/:type/:id', skyid.captchaAssets);
  router.get('/servicesignup/service/*', skyid.getServiceSignUp);

  // Sky ID - Reset Password
  router.get('/resetpassword/service/*', skyid.getResetPasswordForm);
  router.post('/resetpassword/service/*', skyid.postResetPasswordForm);
  router.get('/resetpassword/byemail/:token/service/*', skyid.getNewPasswordForm);
  router.post('/resetpassword/byemail/reset/service/*', skyid.postNewPasswordForm);
  router.get('/resetpassword/email/:returnUrl/:email', skyid.newPasswordEmail);
  router.get('/external-reset-password', skyid.getExternalResetPasswordPage);

  // Oogway
  router.get('/oogway/public/profile', oogwayProfile.publicProfile);
  router.post('/oogway/oauth/authorization/secureid', userToken.getBTLinkedUserToken);

  // Search suggest
  router.get('/search*', searchSuggest.get);

  // Entity search
  router.get('/suggest/v1/:proposition/:section/0/0/:userId/', entitySearch.get);

  // Account Manager
  router.get('/commerce/account-manager/account', accountManager.getAccountDetails);
  router.put('/commerce/account-manager/account', accountManager.createOrUpdateAccountDetails);
  router.get('/commerce/account-manager/account/parental-control', accountManager.getParentalControl);
  router.put('/commerce/account-manager/account/parental-control', accountManager.putParentalControl);
  router.post(
    '/commerce/account-manager/account/cancellation-offers/subscriptionType/*',
    accountManager.getCancellationOffer
  );
  router.get('/reset-fixtures/account/parental-control', accountManager.resetParentalControlFixtures);
  router.get('/reset-fixtures/account/account-details', accountManager.resetAccountDetailsFixtures);

  // Payments Manager
  router.post('/commerce/payments-manager/user/paymentpin/enable', paymentPin.enable);
  router.put('/commerce/payments-manager/user/paymentpin/disable', paymentPin.disable);
  router.post('/commerce/payments-manager/user/paymentpin/reset', paymentPin.reset);
  router.get('/reset-fixtures/paymentpin', paymentPin.resetFixtures);
  router.post('/commerce/payments-manager/user/paymentaccount', paymentAccounts.postSingle);
  router.get('/reset-fixtures/paymentaccount', paymentAccounts.resetFixtures);
  router.get('/commerce/payments-manager/entitlements', entitlements.get);
  router.get('/entitlements', pvsEtitlements.get);
  router.post('/entitlements/activate', activate.post);
  router.get('/commerce/payments-manager/subscriptions/latest', subscriptions.get);
  router.post('/commerce/payments-manager/cancelrenewal', cancelRenewal.post);
  router.post('/commerce/payments-manager/reinstatesubscription', reinstateSubscription.post);
  router.get('/reset-fixtures/payments', sales.resetFixtures);
  router.get('/commerce/payments-manager/orderhistory', orderHistory.get);

  // Payments Manager - bridge endpoint
  router.get('/commerce/bridge/user/paymentaccounts', paymentAccounts.get);
  router.get('/commerce/bridge/user/paymentpin/pinrequired', paymentPin.pinRequired);
  router.get('/commerce/bridge/voucher/:voucherId', vouchers.get);
  router.post('/commerce/bridge/availableproducts', availableProducts.post);
  router.post('/commerce/bridge/charges', sales.priceBasket);
  router.post('/commerce/bridge/order', sales.purchaseBasket);

  // Payments - 3D Secure
  router.get('/3dsecure', threeDSecure.get);

  // Credit Manager
  router.get('/commerce/credit-manager/balance', creditManager.get);

  // Menu
  router.get('/v3/query/menu', menu.menu);

  // Entertainment asset details
  router.get('/v3/query/node/309a4a2e-321a-47d9-93ef-53f6ef633f95', ctx => {
    if (ctx.query.represent && ctx.query.represent.includes('recs')) {
      return getAtomMockForTerritory(ctx, 'slugs', 'entertainment-recommendations');
    } else if (ctx.query.represent && ctx.query.represent.includes('items')) {
      return getAtomMockForTerritory(ctx, 'nodes', 'entertainment-asset-details');
    }
  });

  // Entertainment asset details binge
  router.get('/v3/query/node/babaa6a0-96bf-11e6-9e7e-4b519afca2b9', ctx => {
    if (ctx.query.represent && ctx.query.represent.includes('recs')) {
      return getAtomMockForTerritory(ctx, 'slugs', 'entertainment-recommendations-episode');
    } else if (ctx.query.represent && ctx.query.represent.includes('items')) {
      return getAtomMockForTerritory(ctx, 'nodes', 'entertainment-asset-details');
    }
  });

  // Labelling feed
  router.get('/v3/labels', labellingFeed.get);

  // Supported languages
  router.get('/v3/query/languages', supportedLanguages.get);

  // Sports fixtures
  router.get('/v3/query/page/fixtures', sportsFixtures.get);

  // Static ID queries
  router.get('/v3/query/node/static_id/:staticId(.*)', queryStaticId.getNode);

  // Promotions
  router.get('/v3/query/promotions', promotions);

  // Now Next
  router.get('/atlantis/linear/nownext/:keys', nowNext.get);

  // Recently Watched
  router.get('/bookmarking/bookmarks', bookmarks.get);
  router.get('/v3/query/node/content_id/:contentId', bookmarks.getByContentId);

  // Linear channels
  router.get('/v3/query/linear_channels', linearChannels.get);

  // Content certificates
  router.get('/v3/query/refdata/ott_certificate', ottCertificate.get);

  // Subtitle/audio language defaults
  router.get('/v3/query/audioSubtitle', audioSubtitle.get);

  // Config files
  router.get(
    '/international/:static/:hash/config/:territory/:provider/:proposition/:platform/:environment/config.json',
    config.get
  );
  router.get('/config/:territory/:provider/:proposition/:platform/:environment/:version/config.json', config.get);
  router.get(
    '/config/:territory/:provider/:proposition/:platform/:device/:environment/:version/config.json',
    config.get
  );

  // Playouts
  router.post('/video/playouts/vod', playoutsVOD.post);
  router.post('/video/playouts/live', playoutsLive.post);
  router.post('/play-preview/playouts/vod', playPreview.post);

  // ATOM widgets
  router.get('/v3/query/widget_content', req => {
    const {
      query: { slug },
    } = req;

    if (slug.includes('/widget/eng/the_legal_bit')) {
      legalBit.get(req);
    } else if (slug.includes('/widget/eng/privacy')) {
      privacy.get(req);
    } else if (slug.includes('/widget/eng/terms')) {
      terms.get(req);
    } else {
      switch (slug) {
        case '/crosstv-help':
          widgets.getHelp(req);
          break;
        case '/youi-help':
          widgets.getYouiHelp(req);
          break;
        case '/widget/eng/xtv/settings':
          widgets.getSettings(req);
          break;
        case '/promo/lg':
        case '/promo/appletv':
        case '/promo/roku':
          promoPage.get(req);
          break;
        case '/impressum-sky-ticket-de':
          widgets.getLegalText(req);
          break;
        case '/shop':
          widgets.getShop(req);
          break;
        case '/shop-v1':
          widgets.getShop(req);
          break;
        case '/shop-v2':
          widgets.getShop(req);
          break;
        case '/shop-other':
          widgets.getShopOtherV1(req);
          break;
        case '/shop-other-v1':
          widgets.getShopOtherV1(req);
          break;
        case '/shop-other-v2':
          widgets.getShopOtherV2(req);
          break;
        case '/web_faqs':
          widgets.getFaqs(req);
          break;
        case '/in-app-purchase':
          widgets.getPurchase(req);
          break;
        case '/watch-upsell-banner':
          widgets.getWatchUpsellBanner(req);
          break;
        case '/bt-marketing-entertainment':
          widgets.getBtUpsellEntertainment(req);
          break;
        case '/bt-marketing-sports':
        case '/bt-marketing-movies':
        case '/bt-marketing-kids':
          widgets.getBtUpsellSports(req);
          break;
        case '/boost-cross-sell':
          widgets.getBoostCrossSell(req);
          break;
        case '/boost-cross-sell-comparison':
          widgets.getBoostCrossSellComparison(req);
          break;
        case '/roku-datenschutz-and-cookies-de-1':
          widgets.getLegalText(req);
          break;
        default:
          req.status = 400;
          break;
      }
    }
  });

  // Player download
  router.get('/download-web-player', ctx => {
    const filePath = path.resolve(__dirname, './player.txt');
    ctx.body = fs.createReadStream(filePath);
    ctx.attachment(filePath);
  });

  // MyTV - Watchlist
  router.get('/watchlist', mytvWatchlist.get);
  router.put('/watchlist/:uuid', mytvWatchlist.put);
  router.del('/watchlist/:uuid', mytvWatchlist.del);
  router.del('/watchlist/current', mytvWatchlist.delAll);

  // Recently Viewed
  router.get('/recentlyviewed', recentlyViewed.get);

  // Continue Watching
  router.get('/continuewatching', continueWatching.get);

  // Personalised Recommendations
  router.get('/recommendations/entertainment', personalisedRecsEntertainment.get);
  router.get('/recommendations/movies', personalisedRecsMovies.get);
  router.get('/recommendations', personalisedRecsMixed.get);

  // ATOM collections
  router.get('/v3/query/collection/movies/collections/:collection', ctx =>
    getAtomMockForTerritory(ctx, 'collections', 'movies-single-listing')
  );
  router.get('/v3/query/collection/:section/collections/:collection', ctx =>
    getAtomMockForTerritory(ctx, 'collections', `${ctx.params.section}-${ctx.params.collection}`)
  );
  router.get('/v3/query/collection_id/:collection', ctx =>
    getAtomMockForTerritory(ctx, 'collections', ctx.params.collection)
  );
  router.get('/v3/query/node/778e75a4-ad9a-11e6-b6f5-c3337b9d81a6', ctx =>
    getAtomMockForTerritory(ctx, 'collections', 'entertainment-MixedCollection')
  );
  router.get('/v3/query/node/collection_id/:collection', ctx =>
    getAtomMockForTerritory(ctx, 'collections', ctx.params.collection)
  );
  router.get('/v3/query/group/:group*', ctx => getAtomMockForTerritory(ctx, 'groups', ctx.params.group));
  router.get('/v3/query/group_id/Home', ctx => getAtomMockForTerritory(ctx, 'groups', 'home'));
  router.get('/v3/query/node/group_id/Home', ctx => getAtomMockForTerritory(ctx, 'groups', 'home'));
  router.get('/v3/query/node/provider_series_id/:providerSeriesId', ctx =>
    getAtomMockForTerritory(ctx, 'providerSeriesId', ctx.params.providerSeriesId)
  );

  // ATOM routes, slugs, and nodes
  router.get('/favourites/kids', ctx => getAtomMockForTerritory(ctx, 'nodes', 'kids-favourites'));
  router.get('/v3/query/node', ctx => getAtomMockForTerritory(ctx, 'nodes', ctx.query.slug));
  router.get('/v3/query/slug/:slug*', ctx => getAtomMockForTerritory(ctx, 'slugs', ctx.params.slug));
  router.get('/v3/query/node/provider_variant_id/:id', ctx => getAtomMockForTerritory(ctx, 'nodes', ctx.params.id));
  router.get('/v3/query/node/:node*', ctx => getAtomMockForTerritory(ctx, 'nodes', ctx.params.node));
  router.get('/v3/query/nodes/uuid/:node*', ctx => getAtomMockForTerritory(ctx, 'nodes', ctx.params.node));
  router.get('/v3/query/node/uuid/:node*', ctx => getAtomMockForTerritory(ctx, 'nodes', ctx.params.node));
  router.get('/v3/query/node', ctx => getAtomMockForTerritory(ctx, 'nodes', ctx.query.slug));

  // UK My Account
  router.get('/gb/my-account', externalMyAccount.get);

  // Persona Store
  router.get('/persona-store/personas', personaStore.get);
  router.post('/persona-store/personas', personaStore.post);
  router.put('/persona-store/personas/:personaId', personaStore.put);

  // Time service
  router.get('/time', timeService.get);

  router.post('/lightstreamer/create_session.txt', lightstreamer.createSession);

  // MVPD Gateway Service
  router.get('/mgs/mvpd', mgs.mvpd);
  router.get('/mgs/mvpdData', mgs.mvpdData);

  // Partner Account Manager
  router.get('/pam/lookup', pam.lookup);

  // Adobe Primetime Service
  router.get('/v1/tokens/authn.json', adobePrimetimeService.authn);
  router.get('/v1/config/bravo.json', adobePrimetimeService.bravo);
  router.post('/v1/bravo/regcode.json', adobePrimetimeService.regcode);

  // Test assets proxy
  app.use(
    proxy('/test-assets', {
      target: 'http://staticresources.client.staging.ott.sky.com',
      changeOrigin: true,
      agent: new http.Agent(),
      logs: true,
    })
  );

  // Reset mocks
  router.get('/reset-fixtures/all', ctx => {
    skyid.resetFixtures(ctx);
    paymentPin.resetFixtures(ctx);
    paymentAccounts.resetFixtures(ctx);
    sales.resetFixtures(ctx);
    accountManager.resetParentalControlFixtures(ctx);
    mytvWatchlist.delAll(ctx);
  });

  // Clone management
  router.post('/clone', skyid.createClone);
  router.delete('/clone/:id', skyid.removeClone);

  router.all('*', ctx => {
    ctx.status = 404;
  });

  app.use(router.routes());
  app.ws.use(lightstreamer.websocket);
};
