const crypto = require('crypto');

module.exports.createSession = ctx => {
  const sessionId = crypto.randomBytes(15).toString('hex');
  ctx.body = [
    `CONOK,${sessionId},50000,0,${ctx.request.header.host.split(':')[0]}`,
    'SERVNAME,Lightstreamer HTTPS Server',
    'CLIENTIP,90.216.134.195',
    'CONS,unlimited',
    'LOOP,0',
  ].join('\r\n');
  ctx.status = 200;
  ctx.type = 'text/enriched; charset=UTF-8';
};

module.exports.websocket = ctx => {
  ctx.websocket.on('message', message => {
    if (message.startsWith('bind_session')) {
      const sessionId = message.split('LS_session=')[1].split('&LS_phase')[0];
      ctx.websocket.send(`CONOK,${sessionId},50000,0,${ctx.request.header.host.split(':')[0]}`);
      ctx.websocket.send(`CONS,unlimited`);
    }

    if (message.startsWith('control')) {
      ctx.websocket.send(`SUBOK,1,1,1
      CONF,1,unlimited,filtered`);
      ctx.websocket.send(`REQOK,1`);

      const buttons = message.includes('TV_LG')
        ? [{ label: 'Back', action: 'later', attributes: {} }]
        : [
            { label: 'Remind me later', action: 'later', attributes: {} },
            {
              label: 'Go To My Account',
              action: 'payment',
              attributes: {
                key1: 'PAYMENT_DETAILS',
              },
            },
          ];

      const notification = {
        version: '1.0',
        information: {
          ipnActivityTypeVersion: '1.0',
          provider: 'NOWTV',
          proposition: 'NOWTV',
          territory: 'GB',
          acmCampaignId: 'ross9',
        },
        customer: {
          acmTrackingId: 'tyuiuytre',
          acmBroadlogId: 'khjwerfk89928374234',
        },
        target: { customer: { customer_id: '34503590', acm_broadlog_id: 'broadlogid' } },
        notification: {
          applicationContext: 'Home',
          ipnMessageType: 'Payment',
          ipnFormTitle: 'Payment Failure AB Testing v1',
          devicePlatformModels: 'COMPUTER_PC',
          clientTemplateType: 'Pop-Up-A1',
          atom: true,
          ipnTitle: { short: 'Sorry, no watchy', long: "Sorry, we couldn't take your payment" },
          ipnMessageBody: {
            short: 'Please find out more in My Account.',
            long:
              'This could be for a variety of reasons, please find out more in My Account to continue watching your favourite shows.',
          },
          image: 'credit-card',
          buttons,
        },
      };

      ctx.websocket.send(`U,1,1,${JSON.stringify(notification)}`);
    }
  });
};
