const programmeAsset = require('../pcms/nodes/movie-asset-details');
const seriesAsset = require('../pcms/slugs/entertainment-recommendations');
const userIdentifier = require('../../utils/user-identifier');
const { isScenario } = require('../../utils/scenario');

const seriesUuids = ['c6c0d6e6-7a63-45d0-bb16-expired', '309a4a2e-321a-47d9-93ef-53f6ef633f95'];
const expiredUuids = ['expiredassetuuid'];

function createItem(uuid, asset, expired) {
  const attributes = expired
    ? {
        ...asset.attributes,
        formats: {
          UNKNOWN: {
            availability: {
              available: false,
            },
          },
        },
      }
    : asset.attributes;

  return {
    ...asset,
    attributes: {
      ...attributes,
      programeUuid: uuid,
      seriesUuid: uuid,
    },
  };
}

function getWatchlist({ persistentStore }) {
  const watchlist = persistentStore.get('watchlist');
  return watchlist ? [...watchlist] : [];
}

module.exports.get = function(ctx) {
  const user = userIdentifier.getDataForUserOrDefault(ctx);

  if (user.hasWatchlistData) {
    const assets = [
      createItem(
        '309a4a2e-321a-47d9-93ef-53f6ef633f95',
        programmeAsset,
        expiredUuids.includes('309a4a2e-321a-47d9-93ef-53f6ef633f95')
      ),
      createItem(
        '309a4a2e-321a-47d9-93ef-53f6ef633f95',
        seriesAsset,
        expiredUuids.includes('309a4a2e-321a-47d9-93ef-53f6ef633f95')
      ),
    ];
    ctx.persistentStore.set('watchlist', assets);
    ctx.body = {
      assets,
      count: assets.length,
    };
  } else {
    const assets = getWatchlist(ctx);

    ctx.body = {
      assets,
      count: assets.length,
    };
  }
};

module.exports.put = function(ctx) {
  const watchlist = getWatchlist(ctx);
  const uuid = ctx.params.uuid;

  if (isScenario(ctx, 'watchlist_uuid_not_found')) {
    ctx.status = 404;
    ctx.body = {
      errorCode: 'UUID_NOT_FOUND_OR_NOT_AVAILABLE',
    };
  } else if (
    watchlist.includes(uuid) ||
    uuid === '43c  32824-cff9-4edc-8b9d-27bc701af5d4' ||
    isScenario(ctx, 'watchlist_already_added')
  ) {
    ctx.status = 409;
    ctx.body = {
      errorCode: 'PROGRAMME_ALREADY_EXISTS_IN_SMARTLIST',
      message: `Entry ${uuid} is already in the smartlist`,
    };
  } else {
    const asset = seriesUuids.includes(uuid) ? seriesAsset : programmeAsset;

    watchlist.push(createItem(uuid, asset, expiredUuids.includes(uuid)));
    ctx.persistentStore.set('watchlist', watchlist);

    ctx.status = 204;
    ctx.body = null;
  }
};

module.exports.del = function(ctx) {
  const watchlist = getWatchlist(ctx);
  watchlist.splice(watchlist.findIndex(item => item.uuid === ctx.params.uuid), 1);
  ctx.persistentStore.set('watchlist', watchlist);

  ctx.status = 204;
  ctx.body = null;
};

module.exports.delAll = function(ctx) {
  ctx.persistentStore.delete('watchlist');

  ctx.status = 204;
  ctx.body = null;
};
