const { isScenario } = require('../../utils/scenario');
const { getDataForUserOrDefault } = require('../../utils/user-identifier');

const defaultVouchers = require('./njp/user-voucher-details');

module.exports.get = function(ctx) {
  const user = getDataForUserOrDefault(ctx);
  const authHeader = ctx.request.get('Authorization');

  if (!authHeader.startsWith('NowTV-Auth ')) {
    ctx.body = {
      errors: [
        {
          code: 'request_cannot_be_completed',
          description: 'Invalid request missing header: Authorization',
        },
      ],
    };
    ctx.status = 400;
  } else if (authHeader.includes('undefined')) {
    ctx.body = {
      errors: [
        {
          code: 'UMV_302',
          description: 'Security Failure',
        },
      ],
    };
    ctx.status = 401;
  } else if (isScenario(ctx, 'user_voucher_details_expired_token')) {
    ctx.body = {
      errors: [
        {
          code: 'UMV_005',
          description: 'Expired OTT user token',
        },
      ],
    };
    ctx.status = 401;
  } else if (isScenario(ctx, 'get_vouchers_server_error')) {
    ctx.status = 500;
    return;
  } else {
    ctx.body = user.storedVouchers || defaultVouchers;
    ctx.status = 200;
  }

  ctx.type = 'application/json';
};
