const cloneDeep = require('lodash/cloneDeep');

const users = require('../sky-id/sky-id/users');
const userIdentifier = require('../../utils/user-identifier');
const { isScenario } = require('../../utils/scenario');

module.exports.publicProfile = function(ctx) {
  const user = users[userIdentifier.getUserWithCorrespondingSkyIdToken(ctx)];
  const token = ctx.get('X-SkyId-Token');

  if (token.includes('Session undefined')) {
    ctx.status = 403;
    ctx.body = require('./oogway/invalid-auth');
  } else if (token.includes('Session 01-opt_out') || token.includes('OAuth2 01-opt_out')) {
    ctx.body = require('./oogway/profile-opt-out');
  } else if (token.includes('Session 01-uk_user')) {
    ctx.body = require('./oogway/profile-uk');
  } else {
    const profile = cloneDeep(require('./oogway/profile'));

    profile.profile.id.aliases.email.alias = `${user.username}@cena.com`;
    profile.profile.id.trackingid = ctx.cookies.get('skyCEsidtrk01');
    profile.profile.details.username = user.username;

    if (ctx.persistentStore.get('globalBookmarkingOptOut') !== undefined) {
      profile.profile.globalbookmarkingoptout = ctx.persistentStore.get('globalBookmarkingOptOut');
    }

    if (
      !user.fullySignedUp ||
      isScenario(ctx, 'commerce_no_payment_account') ||
      isScenario(ctx, 'payment_paypal_refused') ||
      isScenario(ctx, 'payment_paypal_error') ||
      isScenario(ctx, 'payment_paypal_rejected_error') ||
      isScenario(ctx, 'payment_paypal_auth_rejected')
    ) {
      if (!ctx.persistentStore.get('fullySignedUp')) {
        Object.keys(profile.profile.services).forEach(serviceName => {
          profile.profile.services[serviceName].fullysignedup = false;
        });
      }
    }
    ctx.body = profile;
  }
};
