const entertainmentRecommendations = require('../slugs/entertainment-recommendations');
const entertainmentRecommendationsSingularSeason = require('../slugs/entertainment-recommendations-singular-season');
const entertainmentRecommendations2 = require('../slugs/entertainment-recommendations2');
const { isScenario } = require('../../../utils/scenario');

const watchlistItem = require('./movie-asset-details');
const expiredEntertainment = require('./expired-entertainment-asset-details'); // eslint-disable-line import/order

const sortable = {
  availableEpisodeCount: 0,
  availableSeasonCount: 0,
  createdDate: 0,
  rightsOwner: '',
  sortTitle: '',
  synopsisBrief: '',
  synopsisLong: '',
  synopsisMedium: '',
  synopsisShort: '',
  title: '',
  titleMedium: '',
};
function alphabeticalSort(attributeToSortBy) {
  return (a, b) => {
    const attributeA = a.attributes[attributeToSortBy].toUpperCase();
    const attributeB = b.attributes[attributeToSortBy].toUpperCase();
    if (attributeA < attributeB) {
      return -1;
    }
    if (attributeA > attributeB) {
      return 1;
    }
    return 0;
  };
}

function numericSort(attributeToSortBy) {
  return (a, b) => a.attributes[attributeToSortBy] - b.attributes[attributeToSortBy];
}

function getSort(attributeToSortBy) {
  const typeOfAttributeToSortBy = typeof sortable[attributeToSortBy];
  if (typeOfAttributeToSortBy === 'string') {
    return alphabeticalSort(attributeToSortBy);
  }
  if (typeOfAttributeToSortBy === 'number') {
    return numericSort(attributeToSortBy);
  }
  return () => 0;
}

function orderby(items, sortType) {
  const [attributeToSortBy, sortDirection] = sortType.match(/[a-zA-Z]+/g);
  const sortedItems = items.sort(getSort(attributeToSortBy));
  return sortDirection === 'asc' ? sortedItems : sortedItems.reverse();
}

function take(items, amount) {
  const sliceTo = amount || items.length;
  return items.slice(0, Number(sliceTo));
}

function skip(items, amount) {
  return items.map(item => {
    const amountToSkip = Number(amount);
    item.id = amountToSkip > 0 ? item.id + amountToSkip : item.id;
    item.attributes.title = amountToSkip ? `${item.attributes.title} Skipped - ${amountToSkip}` : item.attributes.title;
    return item;
  });
}

const functions = {
  orderby,
  take,
  skip,
};

function handlePCMSQueries(mockData) {
  return ctx => {
    const newMockData = JSON.parse(JSON.stringify(mockData));
    const {
      query: { represent },
    } = ctx;
    /*
      '(items[orderby=(createdDate{desc}),take=24,skip=48])'.match(/([a-z]+=\(?[a-zA-Z0-9{}\)]+)[^,\)\]]?/g)
                            =
      [orderby=(createdDate{desc}), take=24, skip=0]
    */
    const rules = represent.match(/([a-z]+=\(?[a-zA-Z0-9{})]+)[^,)\]]?/g);
    const items = newMockData.relationships.items.data;
    if (rules) {
      const modifiedItems = rules.reduce((newItems, rule) => {
        const [key, value] = rule.split('=');
        const functionToRun = functions[key];
        return functionToRun ? functionToRun(newItems, value) : newItems;
      }, items);
      newMockData.relationships.items.data = modifiedItems;
    }
    return newMockData;
  };
}

const bingeWatchingEpisodeMock = require('./binge-watching-episode');
const kidsBingeWatchingEpisodeMock = require('./kids-binge-watching-standalone-episode');

const defaultNodes = {
  'grouchy-young-men/bd4c1848a1496510VgnVCM1000000b43150a____': require('./entertainment-asset-details'),
  'californication/ff1e17011b062510VgnVCM1000000b43150a____': require('./entertainment-asset-details'),
  'strike-back/dccd84ae-49be-11e6-a1e7-fbf9556477c0': require('./entertainment-asset-details'),
  '1a657ad4-49b9-11e6-8b2f-e34ef486e358': require('./entertainment-asset-details'),
  '9b5ab7c8-74d7-11e6-9ac6-8bb0fe31e9d2': require('./entertainment-asset-details'),
  'c6c0d6e6-7a63-45d0-bb16-8602622c8f8e': require('./entertainment-asset-details'),
  'c6c0d6e6-7a63-45d0-bb16-expired': require('./expired-entertainment-asset-details'),
  'entertainment-asset-details': require('./entertainment-asset-details'),
  'atlanta-plastic/128db5ae-54b0-11e6-a5d6-bf41d85c99d2': require('./entertainment-asset-details'),
  '1a042ec6-ad93-11e6-b0fc-0f6df31ff06a': require('./standalone-entertainment-asset-details'),
  '309a4a2e-321a-47d9-93ef-53f6ef633f95': entertainmentRecommendations,
  '309a4a2e-321a-47d9-93ef-53f6ef633f96': entertainmentRecommendations,
  '309a4a2e-321a-47d9-93ef-53f6ef633f97': entertainmentRecommendations,
  '309a4a2e-321a-47d9-93ef-53f6ef633f98': entertainmentRecommendations,
  '309a4a2e-321a-47d9-93ef-53f6ef633f99': entertainmentRecommendations,
  'bcb41422-96c0-11e6-b91c-174a4fbb6b39': entertainmentRecommendations,
  '02e9dd28-f440-11e6-a090-af81bd5abb05': require('./entertainment-asset-details-future-episodes'),
  '377d787a-39a4-11e7-a484-5b220f2d352a': require('./entertainment-asset-details-small-season'),
  '40814f0a-46b0-11e7-b3d9-afe49efbda16': require('./entertainment-asset-details-multiple-seasons'),
  validentertainmentuuid: entertainmentRecommendations,

  '081a38c8-080f-11e7-b611-cf998684f697': ctx =>
    isScenario(ctx, 'binge_watching_watch_now') && bingeWatchingEpisodeMock,

  'b7c44ce6-413f-11e7-ba18-171fc9dc8fb0': ctx =>
    isScenario(ctx, 'binge_watching_watch_now') && kidsBingeWatchingEpisodeMock,

  // Expired entertainment
  'shameless/e2ed137877f35510VgnVCM1000000b43150a____': expiredEntertainment,
  'ee530b94-49ba-11e6-843b-5fb452b2683f': expiredEntertainment,

  // Collections
  'b72c4f20-4755-11e6-994f-07b121981060': require('./all-collections'),
  '870a3d14-40bc-11e7-a5f6-7f7f71c42f66': handlePCMSQueries(require('../groups/movies-genres-collections')),
  'a640c18c-40bf-11e7-9533-b313f5e781d6': handlePCMSQueries(require('../groups/entertainment-genres-collections')),
  'd30a3364-ad95-11e6-b795-e78251eaabaa': require('../collections/movies-mixed-collection'),
  '864ac474-eec9-11e6-92b6-53f693add8c9': require('../collections/family-faves-collection'),

  // Entertainment Channels
  '796fa4d2-34c8-11e7-a838-5f6d7cd87daa': handlePCMSQueries(require('./entertainment-sky1')),
  '7f6d12f2-34c8-11e7-aba0-6ffad9866733': handlePCMSQueries(require('./entertainment-sky-living')),
  '70f9f1e0-34c8-11e7-a3e5-4b5df5132bd1': handlePCMSQueries(require('./entertainment-sky-atlantic')),
  '6c33b43e-34c8-11e7-a08d-d302b382f4cc': handlePCMSQueries(require('./entertainment-sky-gold')),
  '6b9cecde-34c8-11e7-a040-c3a8e4a598a3': handlePCMSQueries(require('./entertainment-comedy-central')),
  '74e98aea-34c8-11e7-a5f9-778463450293': handlePCMSQueries(require('./entertainment-comedy-central')),
  '6b87a626-34c8-11e7-a035-db51f8fcf9c1': handlePCMSQueries(require('./entertainment-comedy-central')),
  '7da57220-34c8-11e7-aab0-9b4bf2b94f86': handlePCMSQueries(require('./entertainment-comedy-central')),
  '756ee8c0-34c8-11e7-a63c-77366126c245': handlePCMSQueries(require('./entertainment-comedy-central')),
  '7cc587fa-34c8-11e7-aa33-0bafe9ea090f': handlePCMSQueries(require('./entertainment-comedy-central')),
  '803f2422-34c8-11e7-abff-2f88ed6f8601': handlePCMSQueries(require('./entertainment-comedy-central')),
  '739b03f8-34c8-11e7-a53c-4f04ada192d8': handlePCMSQueries(require('./entertainment-comedy-central')),
  '78bb39c0-34c8-11e7-a7dd-e3931fef5385': handlePCMSQueries(require('./entertainment-comedy-central')),

  // Movie genres
  '8d54c65e-f43f-11e6-a090-5f0a4111db4c': handlePCMSQueries(require('./movie-genres-all')),
  '9e927c92-474a-11e6-b04c-1f26dc512ebc': handlePCMSQueries(require('./movie-genres-comedy')),
  '8a4808b8-f43f-11e6-a090-bb6583173d87': handlePCMSQueries(require('./movie-genres-comedy')),
  '9e7cabd8-474a-11e6-b04c-9ff31c096e14': handlePCMSQueries(require('./movie-genres-action')),
  '52084766-4750-11e6-8dd2-c335b0eb9766': handlePCMSQueries(require('./movie-genres-showcase')),
  '89b2ce60-f43f-11e6-a090-2b835e67358b': handlePCMSQueries(require('./movie-genres-drama')),
  '8abfd47e-f43f-11e6-a090-874cbae5e218': handlePCMSQueries(require('./movie-genres-drama')),
  '8b46586e-f43f-11e6-a090-1bce8ae3b2b7': handlePCMSQueries(require('./movie-genres-drama')),

  // Entertainment genres
  '8ad88d7a-f43f-11e6-a090-6366eddcd6e5': handlePCMSQueries(require('./entertainment-genres-all')),
  '71abeaa2-33ed-11e7-896a-efc36745422d': handlePCMSQueries(require('./entertainment-genres-documentary')),
  '69321c7a-33ed-11e7-bd60-2b311e5db55c': handlePCMSQueries(require('./entertainment-genres-music-and-arts')),
  '8c5c8d36-f43f-11e6-a090-1fa1ab773491': handlePCMSQueries(require('./entertainment-genres-documentary')),
  '82f32cda-33ed-11e7-95e7-abf5a8f28530': handlePCMSQueries(require('./entertainment-genres-documentary')),

  // HayU genres
  '069603e0-2b83-11e8-9b7c-4b6b0be1e026': require('./hayu-collection1'),
  'bcfca884-47c9-11e8-bb7b-5f1a14fbc514': require('./hayu-collection2'),
  'ecb8e4cc-43d5-11e8-af08-9fb49654d300': require('./hayu-season-vanderpump-rules'),
  'ecd01246-43d5-11e8-af08-3356149149ba': require('./hayu-season-vanderpump-rules'),
  'fb007c4c-4160-11e8-89f3-ab18f7ad85a6': require('./hayu-season2'),
  'fb25210a-4160-11e8-a288-cf2e0b341d71': require('./hayu-season2'),
  'ed6f84fc-43d5-11e8-9997-f75706770306': require('./hayu-season-in-ice-cold-blood'),
  'ed4a25c2-43d5-11e8-91a4-07a530127035': require('./hayu-season-in-ice-cold-blood'),
  '85338e28-963d-11e8-9e7c-9734d6754f54': require('./hayu-hot-right-now'),
  iYEQZ29XgR38y1VXRUb2aA: require('./hayu-season-in-ice-cold-blood'),

  // TV genres
  '9a59899a-474a-11e6-b04c-4ba212e58ba1': require('./tv-genres-comedy'),
  '9e9dd1be-474a-11e6-b04c-3f24cb8267b0': require('./tv-genres-family'),
  '9a728a44-474a-11e6-b04c-cfdf278ef1a5': require('./tv-genres-drama'),
  '767bf16a-4750-11e6-9520-9f9a459b5184': require('./tv-genres-featured'),
  'c83226a2-d8f7-11e7-b830-a367dcb8be4f': require('./entertainment-hot-right-now'),
  'b7d27b28-7087-11e7-a31c-e788d49e8385': require('./entertainment-sky-originals'),

  // Movie assets
  e67c197089fc1510VgnVCM1000000b43150a____: require('./movie-asset-details'),
  '06a41fdc-3f82-11e6-a8fb-7f3526605fc6': require('./movie-asset-details'),
  'fd9d1e22-49bb-11e6-8b54-f7b307d942f1': require('./movie-asset-details'),
  '3ea5fc02-49b9-11e6-8b2f-1b63cee46c73': require('./movie-asset-details'),
  'c69249b0-415a-11e7-b766-d7fd04677b39': require('./movie-asset-details'),
  '35f851b6-415e-11e7-9800-8f8b0fee995f': require('./movie-asset-details'),
  '2b19ea40-41f2-11e7-a4a5-07fb8437d513': require('./movie-asset-details'),
  '4b95a930-41f2-11e7-ad00-4fdbb1e65888': require('./movie-asset-details'),
  'eb9af78e-415a-11e7-be26-63ec7dd4fbde': require('./movie-asset-details'),
  '438f9412-41f2-11e7-b716-4fd9f04e20c3': require('./movie-asset-details'),
  'b8775f04-e86b-4a8b-ae8c-fdcf4d9705ac': require('./movie-asset-details'),
  'b8775f04-e86b-4a8b-ae8c-fdcf4d9705ac-watchlist': watchlistItem,
  '52c620c6-39a1-11e7-b6f8-23c34d166927': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166928': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166929': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166930': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166931': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166932': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166933': require('./movie-asset-details'),
  '52c620c6-39a1-11e7-b6f8-23c34d166934': require('./movie-asset-details'),
  '3c371d78-4159-11e7-9953-f3f33931cf1d': require('./movie-asset-details-hd-available'),
  'a2abaab1-b0d5-491b-b6fd-9a91d4cf3a5c': require('./episodic-movie-asset-details'),

  'uuid/226c8913-f33e-41ac-90cf-24f1870dc2b5': require('./movie-asset-details-variant'),
  '226c8913-f33e-41ac-90cf-24f1870dc2b5': require('./movie-asset-details-variant'),
  'uuid/43c32824-cff9-4edc-8b9d-27bc701af5d4': require('./movie-asset-details-variant'),
  '43c32824-cff9-4edc-8b9d-27bc701af5d4': require('./movie-asset-details-variant'),
  'a45a73e0-399e-11e7-9436-4f86168314ef': require('./movie-asset-details-variant'),
  '851db27c-46d2-11e6-9d24-3fb09ecbe3fa': require('./movie-asset-details-variant'),
  '5ded3880-46d2-11e6-ac9a-2f44f2173b27': require('./movie-asset-details-variant'),
  '4bc415ca-74ef-11e6-951c-cb1abaf27d23': require('./movie-asset-details-expired'),

  '5718f998-ad95-11e6-8727-f3f2d7ab9a29': require('./episodic-movie-asset-details'),

  expiredassetuuid: require('./movie-asset-details-expired'),

  'debc9ace-74ee-11e6-a42b-ab6c46d3c7ae': require('./movie-asset-details-error'),
  '32b4f0e2-41f2-11e7-b4fa-3b6f80d03801': require('./movie-asset-details-error-eu-portability'),

  // Device limit error asset
  b41a8ea867510VgnVCM1000000b43150a____: require('./movie-asset-details-device-limit'),
  '4458c25e-415e-11e7-b490-e371185f2e64': require('./movie-asset-details-device-limit'),

  // Kids
  '5783f772-dd90-11e6-9133-5ffa0959dda6': require('./kids-recommendations'),
  '63976bde-6dc2-11e8-8deb-030c1db1a9c1': require('./kids-binge-watching-standalone-episode3'),
  '32b00c4e-6dc5-11e8-9e5b-2ba67b0e4d4e': require('./kids-binge-watching-standalone-episode2'),
  '324b58f8-6dc5-11e8-a415-c3c9741bcc7e': require('./kids-binge-watching-standalone-episode'),
  aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa: require('./kids-recommendations'),
  '6a89c952-6dc5-11e8-b120-634a727716ac': require('./kids-multi-season'),
  'f88334c0-25ad-11e7-9181-173457a2a839': require('./kids-group'),
  'kids-group': require('./kids-group'),
  'kids-favourites': require('./kids-favourites'),

  // Short Form
  '25509872-85dd-11e8-9fa2-cb0d06b98d66': handlePCMSQueries(require('../collections/short-form-collection')),
  '1797cfa2-522e-11e9-bf21-c3d929832ee6': handlePCMSQueries(require('../collections/short-form-movies-collection')),
  '43521c5a-5612-11e9-ab4e-bf7d63ef5fb8': handlePCMSQueries(
    require('../collections/short-form-entertainment-collection')
  ),
  '/short-form': require('../collections/short-form-collection'),
  '/cena-vs-rock': require('../slugs/short-form-asset'),

  // Seamless pages
  '7c2ceeaa-34c8-11e7-a9d9-070d2d46f809': require('../groups/movies-pass-page'),
  '7341d440-34c8-11e7-a510-0739568f63d2': require('../groups/entertainment-pass-page'),
  '09e7949c-72e0-11e8-a8f3-4f10fc04d06e': require('../groups/hayu-pass-page'),
  '3a804332-7152-11e7-9c83-7bfd3775fc25': require('../groups/channels-pass-page'),
  'd9c17bd4-ad91-11e7-bce4-7f5120ce3aea': require('../groups/genres-pass-page'),
  '8230dc2e-f78f-11e6-9535-f32aaa1508ed': require('../groups/gold-channel'),
  '852cf87c-f78f-11e6-9a61-3ff61a12f4f4': require('../groups/comedycentral-channel'),

  // Nodes loaded by SlugLoader
  '/movies/highlights': require('../groups/movie-highlights'),
  '/movies/explorer': require('../groups/movies-explorer-menu'),
  '/movies/collections': require('../collections/movies-multi-listing-page'),
  '/movies/collections/most-popular': require('../collections/movies-single-listing-page'),
  '/movies/collections/play_movies': require('../collections/movies-single-listing-page'),
  '/movies/collections/hero-highlights': require('../collections/movies-single-listing-page'),
  '/american-sniper-2014': require('./movie-asset-details'),
  '/burying-the-ex-2014': require('./movie-asset-details'),
  '/burying-the-ex-expired-2014': require('./movie-asset-details-expired'),
  '/warcraft-2016/804bba33aed2a510VgnVCM1000000b43150a____': require('./movie-asset-details'),
  '/star-wars-the-clone-wars-rookies/e28c9d46-1ab4-47f0-94d3-722c1ea6cabe': require('./episodic-movie-asset-details'),
  '/star-wars-the-clone-wars-rookies/e28c9d46-1ab4-47f0-94d3-722c1ea6cabe/seasons/1/episodes/1': require('./episodic-movie-asset-details'),
  '/star-wars-the-clone-wars-rookies/e28c9d46-1ab4-47f0-94d3-722c1ea6cabe/seasons/1/episodes/2': require('./episodic-movie-asset-details'),
  '/long-way-north-2015/f0e13eda9eeb8510VgnVCM1000000b43150a____': require('./movie-asset-details'),
  '/50-first-dates-2004': require('./movie-asset-details'),
  '/frozen-fever-2015': require('./movie-asset-details'),
  '/dark-signal-2016/277d395b6f2e7510VgnVCM1000000b43150a____': require('./movie-asset-details'),
  '/run-all-night-2014': require('./movie-asset-details'),
  '/run-all-night-2015': require('../nodes/movie-asset-details-variant'),
  '/collections/hero-highlights': require('../collections/movies-single-listing-page'),
  '/entertainment/highlights': require('../groups/entertainment-highlights'),
  '/entertainment/explorer': require('../groups/entertainment-explorer-menu'),
  '/entertainment/collections/factual': require('../collections/entertainment-factual'),
  '/entertainment/collections/comedy': require('../collections/entertainment-comedy'),
  '/entertainment/channels': require('../groups/entertainment-channels'),
  '/entertainment/collections/all-channels-sky1': require('../collections/entertainment-sky1-channels'),
  '/entertainment/collections/all-channels-sky-living': require('../collections/entertainment-gold-channels'),
  '/50-ways-to-kill-your-mammy/ce91caf177930510VgnVCM1000000b43150a____': entertainmentRecommendations,
  '/50-ways-to-kill-your-mammy/ce91caf177930510VgnVCM1000000b43150a____/b76963518d38f410VgnVCM1000000b43150a____/seasons/4': entertainmentRecommendations2,
  '/50-ways-to-kill-your-mammy/ce91caf177930510VgnVCM1000000b43150a____/seasons/3/episodes/2': require('../nodes/entertainment-season-second-episode'),
  '/50-ways-to-kill-your-mammy/ce91caf177930510VgnVCM1000000b43150a____/seasons/3/episodes/1': require('../nodes/entertainment-season-first-episode'),
  '/50-ways-to-kill-your-mammy-once': entertainmentRecommendationsSingularSeason,
  '/home': require('../groups/seamless'),

  '/24-hours-in-trumps-america/57d8d635421bb510VgnVCM1000000b43150a____': require('./standalone-entertainment-asset-details'),
  '/spy/063fc0ac06d50410VgnVCM1000000b43150a____': require('../slugs/entertainment-recommendations'),
  '/sex-and-the-city/4d0f999179364510VgnVCM1000000b43150a____': require('../slugs/entertainment-recommendations'),
  '/shameless/e2ed137877f35510VgnVCM1000000b43150a____': expiredEntertainment,
  '/sports/highlights': require('../groups/sports-highlights'),
  '/sports/collections/featured': require('../collections/sports-wrestling'),
  '/sports/collections/wrestling': require('../collections/sports-wrestling'),
  '/kids/highlights': require('./kids-group'),
  '/icarly/a5fd986a4925f410VgnVCM1000000b43150a____': require('./kids-recommendations'),
  '/icarly/a5fd986a4925f410VgnVCM1000000b43150a____/seasons/3/episodes/1': require('./kids-recommendations'),
  '/icarly/a5fd986a4925f410VgnVCM1000000b43150a____/seasons/3': require('./kids-recommendations'),
  '/icarly/a5fd986a4925f410VgnVCM1000000b43150a____/b76963518d38f410VgnVCM1000000b43150a____/seasons/4': require('./kids-recommendations2'),
  '/the-gruffalo/ad05cbe46bc98510VgnVCM1000000b43150a____': require('./standalone-kids-asset-details'),
  '/kids/collections/kids-collection': require('../collections/kids-collection'),
  '/kids/collections/favourites': require('../collections/kids-collection'),
  '/kids/favourites': require('../collections/kids-collection'),
  '/my-kitchen-rules-usa/920f7b57197af510VgnVCM1000000b43150a____': require('./entertainment-asset-details'),
  '/my-kitchen-rules-usa/920f7b57197af510VgnVCM1000000b43150a____/seasons/1/episodes/3/831b7d8b62abf510VgnVCM1000000b43150a____': require('../nodes/entertainment-asset-details'),
  '/strike-back/dccd84ae-49be-11e6-a1e7-fbf9556477c0': require('./entertainment-asset-details'),
  '/strike-back/dccd84ae-49be-11e6-a1e7-fbf9556477c0/seasons/4/episodes/4': require('./entertainment-asset-details'),
  '/strike-back/dccd84ae-49be-11e6-a1e7-fbf9556477c0/seasons/4/episodes/4/slugslug': require('./entertainment-asset-details'),
  '/the-walking-dead/6960394c49fee410VgnVCM1000000b43150a____': require('../slugs/entertainment-recommendations'),
};

module.exports = {
  ie: defaultNodes,
  gb: defaultNodes,
  it: defaultNodes,
  de: defaultNodes,
  pl: defaultNodes,
  jc: defaultNodes,
};
