const checkHeader = require('../../../utils/check-header');
const { isScenario } = require('../../../utils/scenario');

const getFixture = (widget, options = []) => ctx => {
  const header = ctx.request.header;
  let widgetToLoad = widget;

  if (!checkHeader.isCorrectPCMSHeader(header)) {
    return (ctx.status = 400);
  }

  let filename = options.map(opt => header[`x-skyott-${opt}`].toLowerCase()).join('.');

  if (isScenario(ctx, 'shop_ufp_configuration')) {
    filename = `${filename}-ufp`;
  }

  if (isScenario(ctx, 'boost_cross_sell_comparison') && widget === 'boost-cross-sell') {
    widgetToLoad = 'boost-cross-sell-comparison';
  }

  if (isScenario(ctx, 'get_widget_fails')) {
    return (ctx.status = 400);
  }

  try {
    ctx.body = require(`../../widgets/${widgetToLoad}/${filename}.json`);
  } catch (e) {
    ctx.body = require(`../../widgets/${widgetToLoad}/mock.jc.en.json`);
  }
};

module.exports.getLegalText = getFixture('legal-text', ['language']);
module.exports.getHelp = getFixture('help', ['language']);
module.exports.getYouiHelp = getFixture('youi-help', ['language']);
module.exports.getSettings = getFixture('settings', ['language']);
module.exports.getFaqs = getFixture('faqs', ['proposition', 'territory', 'language']);
module.exports.getShop = getFixture('shop', ['proposition', 'territory', 'language']);
module.exports.getShopOtherV1 = getFixture('shop-other-v1', ['proposition', 'territory', 'language']);
module.exports.getShopOtherV2 = getFixture('shop-other-v2', ['proposition', 'territory', 'language']);
module.exports.getPurchase = getFixture('in-app-purchase', ['proposition', 'territory', 'language']);
module.exports.getWatchUpsellBanner = getFixture('watch-upsell-banner', ['proposition', 'territory', 'language']);
module.exports.getBtUpsellEntertainment = getFixture('bt-upsell-entertainment', [
  'proposition',
  'territory',
  'language',
]);
module.exports.getBtUpsellSports = getFixture('bt-upsell-sports', ['proposition', 'territory', 'language']);
module.exports.getBoostCrossSell = getFixture('boost-cross-sell');
module.exports.getBoostCrossSellComparison = getFixture('boost-cross-sell-comparison');
