const cloneDeep = require('lodash/cloneDeep');

const users = require('./users');

const CLONES = {};
const CLONES_IDS = {};

function getRealUsersKeys() {
  return Object.keys(users).filter(key => !CLONES[key]);
}

function getClonesIds() {
  return Object.keys(CLONES_IDS);
}

function createUserClone(key, id, store) {
  const cloneId = `${key}_${id}`;

  if (store) {
    store.delete(cloneId);
  }

  if (!users[key]) {
    return;
  }

  CLONES[cloneId] = true;

  users[cloneId] = cloneDeep({
    ...users[key],
    userToken: cloneId,
    skyIdToken: `01-${cloneId}`,
  });
}

function removeUserClone(key, id) {
  const cloneId = `${key}_${id}`;

  if (!users[cloneId]) {
    return;
  }

  CLONES[cloneId] = false;

  delete users[cloneId];
}

function createCloneForAllUsers(id, store) {
  getRealUsersKeys().forEach(key => createUserClone(key, id, store));

  CLONES_IDS[id] = true;
}

function createClonesForUser(key) {
  getClonesIds().forEach(id => createUserClone(key, id));
}

function removeCloneForAllUsers(id) {
  if (!CLONES_IDS[id]) {
    return;
  }

  getRealUsersKeys().forEach(key => removeUserClone(key, id));

  CLONES_IDS[id] = false;
}

module.exports = {
  createCloneForAllUsers,
  createClonesForUser,
  removeCloneForAllUsers,
};
