const { getProfileFixture } = require('./get-profile');

const userDefaults = {
  devices: [
    {
      id: '1234',
      name: 'PC',
      type: 'COMPUTER',
      platform: 'PC',
      createdDate: '2016-03-01T14:34:04Z',
      lastModifiedDate: '2016-03-01T14:34:04Z',
      lastUsedDate: '2016-03-02T09:04:14Z',
      mpodDetails: {},
      details: {},
    },
    {
      id: '2345',
      name: 'MAC',
      type: 'COMPUTER',
      platform: 'PC',
      createdDate: '2016-03-01T14:34:04Z',
      lastModifiedDate: '2016-03-01T14:34:04Z',
      lastUsedDate: '2016-03-01T14:34:14Z',
      mpodDetails: {},
      details: {},
    },
  ],
  registrations: {
    allowedDevicesCount: 4,
    registeredDevicesCount: 2,
    remainingDeviceChangesCount: 3,
    lastAdditionDate: '2016-08-01T13:02:00Z',
    allowedDeviceChangesCount: 1,
  },
  paymentPin: {
    pinRequired: true,
  },
  parentalPin: {
    parentalPin: '1234',
    parentalPinRequired: true,
  },
  paymentAccounts: {
    paymentAccounts: [
      {
        paymentToken: 'ajhdf968ayidohkjq34yahrezsh',
        paymentProvider: 'BC',
        paymentMethod: 'visa',
        lastDigits: '1111',
        expiryDate: '06/22',
        customerReference: 'valid_user',
        cardAlias: '982n4r928n3',
        defaultPaymentAccount: true,
      },
    ],
  },
  entitlements: [
    {
      id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
      name: 'ENTERTAINMENT',
      productId: 'C_002009',
      productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
      state: 'ACTIVATED',
      startDate: '2016-07-29T13:27:18Z',
      billingType: 'Recurring',
      contentSegments: ['ENTERTAINMENT'],
    },
    {
      id: 'b9ed2570-6e63-11e5-9d70-feff819cdc9f',
      name: 'SPORTS',
      productId: 'C_002014',
      productStaticId: 'SPORTS_DAY_PASS',
      state: 'ACTIVATED',
      entitlementDuration: 'P1D',
      startDate: '2016-07-29T00:00:00Z',
      contentSegments: ['SPORTS'],
      endDate: '2016-07-29T23:59:59Z',
      billingType: 'Non_Recurring',
    },
    {
      id: 'a1ab0123-6e63-11e5-9d70-feff819cdc9f',
      name: 'SPORTS',
      productId: 'C_002018',
      productStaticId: 'SPORTS_WEEK_PASS',
      state: 'QUEUED',
      entitlementDuration: 'P1W',
      contentSegments: ['SPORTS'],
      activationStartDate: '2016-07-29T09:43:27Z',
      activationEndDate: '2017-07-29T09:43:27Z',
      billingType: 'Non_Recurring',
    },
    {
      id: '9bb1d400-6da2-11e5-9d70-feff819cdc9f',
      name: 'MOVIES',
      productId: 'C_002002',
      productStaticId: 'CINEMA_SUBSCRIPTION',
      state: 'ACTIVATED',
      contentSegments: ['MOVIES'],
      startDate: '2016-07-29T13:27:18Z',
      billingType: 'Recurring',
    },
    {
      id: '71231cd0-6da2-11e5-9d70-feff819cdc91',
      name: 'KIDS',
      productId: 'C_003116',
      contentSegments: ['KIDS'],
      productStaticId: 'KIDS_SUBSCRIPTION',
      state: 'ACTIVATED',
      startDate: '2016-07-29T13:27:18Z',
      billingType: 'Recurring',
    },
  ],
  subscriptions: [
    {
      id: '18c4ce82-6e12-435d-9151-221efeb12af0',
      startDate: '2016-07-29T13:27:18Z',
      state: 'ACTIVE',
      nextRenewalAmount: '15.00',
      nextRenewalDueDate: '2016-08-29T13:27:18Z',
      product: {
        id: 'C_002009',
        staticId: 'ENTERTAINMENT_SUBSCRIPTION',
        context: {
          subscriptionType: 'MONTHLY',
          offers: [],
        },
      },
      entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
      allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
    },
    {
      id: 'f1498fac-b8cf-4345-8d7d-9aea5815a68b',
      startDate: '2016-07-29T13:27:18Z',
      state: 'USER_CANCELLED',
      cancellationEffectiveDate: '2016-08-29T13:27:18Z',
      product: {
        id: 'C_002002',
        staticId: 'CINEMA_SUBSCRIPTION',
        context: {
          subscriptionType: 'MONTHLY',
          offers: [],
        },
      },
      entitlements: ['9bb1d400-6da2-11e5-9d70-feff819cdc9f'],
      allowedOperations: ['REINSTATE', 'DELETE'],
    },
    {
      id: '18c4ce82-6e12-435d-9151-221efeb12af1',
      startDate: '2016-07-29T13:27:18Z',
      state: 'ACTIVE',
      nextRenewalAmount: '7.00',
      cancellationEffectiveDate: '2016-08-29T13:27:18Z',
      product: {
        id: 'C_003116',
        staticId: 'KIDS_SUBSCRIPTION',
        context: {
          subscriptionType: 'MONTHLY',
        },
      },
      offers: [],
      entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc91'],
      allowedOperations: ['REINSTATE', 'DELETE'],
    },
  ],
  password: 'test1234',
  fullySignedUp: true,
  trialsUsed: [],
  watchlist: [],
};

const users = {
  opt_out: {},
  valid_user: {},
  uk_user: {},
  standard_vsid: {
    entitlements: undefined,
    subscriptions: [],
  },
  user_with_no_stored_vouchers: {
    storedVouchers: [],
  },
  user_with_all_device_types: {
    devices: [
      {
        id: '1234',
        name: 'PC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '1235',
        name: 'Mobile',
        type: 'MOBILE',
        platform: 'ios',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '1236',
        name: 'TV',
        type: 'TV',
        platform: 'something',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '1237',
        name: 'TABLET',
        type: 'TABLET',
        platform: 'something',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '1238',
        name: 'SETTOPBOX',
        type: 'SETTOPBOX',
        platform: 'something',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '1239',
        name: 'IPSETTOPBOX',
        type: 'IPSETTOPBOX',
        platform: 'something',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '1230',
        name: 'CONSOLE',
        type: 'CONSOLE',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
    ],
    registrations: {
      allowedDevicesCount: 7,
      registeredDevicesCount: 7,
      remainingDeviceChangesCount: 1,
      lastAdditionDate: '2016-08-01T13:02:00Z',
      allowedDeviceChangesCount: 1,
    },
  },
  user_without_payment_pin: {
    devices: [
      {
        id: '1234',
        name: 'PC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '2345',
        name: 'MAC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-01T14:34:14Z',
        mpodDetails: {},
        details: {},
      },
    ],
    registrations: {
      allowedDevicesCount: 4,
      registeredDevicesCount: 2,
      remainingDeviceChangesCount: 3,
      lastAdditionDate: '2016-08-20T20:24:00Z',
      allowedDeviceChangesCount: 1,
    },
    paymentPin: {
      errorCode: 'COM_00005',
      description: 'Not Found: <data item>',
    },
  },
  'a1884cesatjenft@sky.uk': {},
  user_with_payment_pin: {
    collectAnalyticsRequests: true,
    devices: [
      {
        id: '1234',
        name: 'PC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '2345',
        name: 'MAC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-01T14:34:14Z',
        mpodDetails: {},
        details: {},
      },
    ],
    registrations: {
      allowedDevicesCount: 4,
      registeredDevicesCount: 2,
      remainingDeviceChangesCount: 3,
      lastAdditionDate: '2016-08-15T23:59:00Z',
      allowedDeviceChangesCount: 1,
    },
    entitlements: [
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2016-10-29T13:27:18Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2016-07-29T13:27:18Z',
            endDate: '2016-10-28T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
  },
  user_with_payment_pin_to_disable: {},
  user_with_disabled_payment_pin: {
    devices: [
      {
        id: '1234',
        name: 'PC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '2345',
        name: 'MAC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-01T14:34:14Z',
        mpodDetails: {},
        details: {},
      },
    ],
    registrations: {
      allowedDevicesCount: 4,
      registeredDevicesCount: 2,
      remainingDeviceChangesCount: 3,
      lastAdditionDate: '2016-08-10T09:30:00Z',
      allowedDeviceChangesCount: 1,
    },
    paymentPin: {
      pinRequired: false,
    },
    entitlements: [
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2016-10-29T13:27:18Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2016-07-29T13:27:18Z',
            endDate: '2016-10-28T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
  },
  user_with_bad_payment_pin: {
    badPaymentPin: true,
    paymentPin: {
      pinRequired: false,
    },
  },
  user_with_no_changes: {
    devices: [
      {
        id: '1234',
        name: 'PC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
      {
        id: '2345',
        name: 'MAC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-01T14:34:14Z',
        mpodDetails: {},
        details: {},
      },
    ],
    registrations: {
      allowedDevicesCount: 4,
      registeredDevicesCount: 2,
      remainingDeviceChangesCount: 0,
      lastAdditionDate: '2016-08-15T13:24:00Z',
      allowedDeviceChangesCount: 1,
    },
  },
  user_with_no_passes: {
    entitlements: undefined,
    subscriptions: [],
  },
  user_with_no_passes_or_cotinue_watching_data: {
    entitlements: undefined,
    subscriptions: [],
    noContinueWatchingData: true,
  },
  user_with_no_passes_payment_pin_disabled: {
    paymentPin: {
      pinRequired: false,
    },
    entitlements: undefined,
    subscriptions: [],
  },
  user_on_purchase_journey: {
    entitlements: undefined,
    subscriptions: [],
  },
  user_on_purchase_in_discovery_journey: {
    entitlements: undefined,
    subscriptions: [],
  },
  watchlist_user: {
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  homepage_watchlist_user: {
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  nba_watchlist_user: {
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  'no_passes@sky.uk': {
    entitlements: undefined,
    subscriptions: [],
    password: 'aaaaaaaa',
  },
  user_with_no_passes_or_parental_pin: {
    parentalPin: {
      parentalPinRequired: false,
    },
    entitlements: undefined,
    subscriptions: [],
  },
  user_with_multipass_trial: {
    entitlements: undefined,
    subscriptions: [],
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  user_with_no_passes_or_payment_pin: {
    paymentPin: {
      errorCode: 'COM_00005',
      description: 'Not Found: <data item>',
    },
    entitlements: undefined,
    subscriptions: [],
  },
  user_with_active_watchlist: {
    hasWatchlistData: true,
  },
  user_with_ufp_pass: {
    entitlements: [
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'CINEMA',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-05-11T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2017-05-11T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2017-08-11T13:27:18Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2017-05-11T13:27:18Z',
            endDate: '2017-08-11T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
  },
  user_with_unlimited_ufp_pass: {
    ineligibleForCancellationOffer: true,
    entitlements: [
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-07-11T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2017-07-11T13:27:18Z',
        state: 'ACTIVE',
        offerAllowed: 'false',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2040-07-11T13:27:18Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            staticId: 'ENTERTAINMENT_SUBSCRIPTION',
            startDate: '2017-07-11T13:27:18Z',
            endDate: '2040-07-11T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
  },
  user_with_multiple_sports_day_pass: {
    entitlements: [
      {
        id: '4d7b834a-1271-472e-a0d8-a32689cfe578',
        name: 'SPORTS',
        productId: 'C_002014',
        productStaticId: 'SPORTS_DAY_PASS',
        state: 'ACTIVATED',
        startDate: '2017-01-12T16:42:47Z',
        endDate: '2017-01-13T16:42:47Z',
        billingType: 'Non_Recurring',
        contentSegments: ['SPORTS'],
      },
      {
        id: 'b8aa9e3b-a8c7-4ae8-be63-c5815c8d7aa3',
        name: 'SPORTS',
        productId: 'C_002014',
        productStaticId: 'SPORTS_DAY_PASS',
        state: 'QUEUED',
        entitlementDuration: 'PT24H',
        activationStartDate: '2017-01-12T16:43:45Z',
        activationEndDate: '2018-01-12T16:43:45Z',
        billingType: 'Non_Recurring',
        contentSegments: ['SPORTS'],
      },
      {
        id: 'f5454dc7-7977-4d36-b24a-7c82375fbb95',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-01-12T16:36:33Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [],
  },
  tracking_user_with_no_passes: {
    collectAnalyticsRequests: true,
    entitlements: undefined,
    subscriptions: [],
  },
  tracking_user: {
    collectAnalyticsRequests: true,
    entitlements: [
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2016-10-29T13:27:18Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2016-07-29T13:27:18Z',
            endDate: '2016-10-28T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
  },
  user_with_trials: {
    entitlements: [
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-09-08T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-09-08T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2016-09-22T13:27:18Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'TRIAL',
            startDate: '2016-09-08T13:27:18Z',
            endDate: '2016-09-22T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
    trialsUsed: ['14_DAYS_ENTERTAINMENT_TRIAL'],
  },
  user_with_trials_used: {
    entitlements: undefined,
    subscriptions: [],
  },
  partial_user_with_trials_used: {
    noPaymentAccount: true,
    hasUsedTrials: true,
    entitlements: undefined,
    subscriptions: [],
  },
  user_with_no_changes_left: {
    devices: [
      {
        id: '1234',
        name: 'PC',
        type: 'COMPUTER',
        platform: 'PC',
        createdDate: '2016-03-01T14:34:04Z',
        lastModifiedDate: '2016-03-01T14:34:04Z',
        lastUsedDate: '2016-03-02T09:04:14Z',
        mpodDetails: {},
        details: {},
      },
    ],
    registrations: {
      allowedDevicesCount: 4,
      registeredDevicesCount: 1,
      remainingDeviceChangesCount: 0,
      lastAdditionDate: '${nextMonth}',
      allowedDeviceChangesCount: 1,
    },
  },
  user_with_expired_card_details: {
    paymentAccounts: {
      paymentAccounts: [
        {
          paymentToken: 'ajhdf968ayidohkjq34yahrezsh',
          paymentProvider: 'BC',
          paymentMethod: 'visa',
          lastDigits: '1234',
          expiryDate: '06/12',
          customerReference: 'user_with_expired_card_details',
          cardAlias: '982n4r928n3',
        },
      ],
    },
  },
  user_without_last_card_digits: {
    entitlements: undefined,
    paymentAccounts: {
      paymentAccounts: [
        {
          paymentToken: 'ajhdf968ayidohkjq34yahrezsh',
          paymentProvider: 'BC',
          paymentMethod: 'visa',
          expiryDate: '06/12',
          customerReference: 'user_without_last_card_digits',
          cardAlias: '982n4r928n3',
        },
      ],
    },
  },
  user_with_mastercard_details: {
    entitlements: undefined,
    paymentAccounts: {
      paymentAccounts: [
        {
          paymentToken: 'ajhdf968ayidohkjq34yahrezsh',
          paymentProvider: 'BC',
          paymentMethod: 'mccommercialpremiumcredit',
          lastDigits: '1234',
          expiryDate: '06/40',
          customerReference: 'user_with_mastercard_details',
          cardAlias: '982n4r928n3',
        },
      ],
    },
  },
  user_with_paypal_details: {
    entitlements: undefined,
    paymentAccounts: {
      paymentAccounts: [
        {
          paymentToken: 'ajhsdgklahurw',
          paymentProvider: 'BC',
          paymentMethod: 'paypal',
          customerReference: '76gaaeryoaeyo8afd',
          cardAlias: '982n4r928n3',
          defaultPaymentAccount: true,
          signupEmail: 'buyer@email.com',
        },
      ],
    },
  },
  user_without_paypal_email_address: {
    entitlements: undefined,
    paymentAccounts: {
      paymentAccounts: [
        {
          paymentToken: 'ajhsdgklahurw',
          paymentProvider: 'BC',
          paymentMethod: 'paypal',
          customerReference: '76gaaeryoaeyo8afd',
          cardAlias: '982n4r928n3',
          defaultPaymentAccount: true,
        },
      ],
    },
  },
  user_with_no_card_details: {
    paymentAccounts: {
      errorCode: 'COM_00005',
      description: 'Payment accounts not found',
    },
  },
  user_fully_signed_up_no_payment_account: {
    fullySignedUp: true,
    noPaymentAccount: true,
    entitlements: undefined,
  },
  user_with_sign_in_captcha: {
    captchaSolution: 'kntmnk',
  },
  user_with_expired_messo: {},
  user_without_parental_pin: {
    collectAnalyticsRequests: true,
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  user_with_parental_pin_no_passes: {
    entitlements: undefined,
    subscriptions: [],
  },
  user_without_parental_pin_and_with_hd_entitlement: {
    entitlements: [
      {
        billingType: 'Non_Recurring',
        endDate: '2019-01-30T23:00:00+00:00',
        id: '766325',
        name: 'pkghd',
        productId: 'C_006602',
        productStaticId: 'pkghd',
        startDate: '2018-06-13T08:28:40+00:00',
        state: 'ACTIVATED',
        contentSegments: ['PKGHD'],
      },
    ],
    subscriptions: [
      ...userDefaults.subscriptions,
      {
        id: '12345e82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2016-08-29T13:27:18Z',
        product: {
          id: '766325',
          staticId: 'pkghd',
          context: {
            subscriptionType: 'MONTHLY',
            offers: [],
          },
        },
        entitlements: ['766325'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  user_with_generic_payment_error: {
    genericPaymentError: true,
    entitlements: undefined,
    subscriptions: [],
  },
  user_never_set_parental_pin: {
    parentalPin: {
      parentalPinNeverSet: true,
    },
  },
  user_never_set_parental_pin_has_mandatory_pin_entitlement: {
    parentalPin: {
      parentalPinNeverSet: true,
    },
    entitlements: [
      {
        id: '9bb1d400-6da2-11e5-9d70-feff819cdc9f',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
    ],
    subscriptions: [
      {
        id: 'f1498fac-b8cf-4345-8d7d-9aea5815a68b',
        startDate: '2016-07-29T13:27:18Z',
        state: 'USER_CANCELLED',
        cancellationEffectiveDate: '2016-08-29T13:27:18Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
            offers: [],
          },
        },
        entitlements: ['9bb1d400-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['REINSTATE', 'DELETE'],
      },
    ],
  },
  user_never_set_parental_pin_no_passes: {
    parentalPin: {
      parentalPinNeverSet: true,
    },
    entitlements: undefined,
    subscriptions: [],
  },
  user_with_unsupported_pass: {
    entitlements: [
      {
        id: '8e5623b2-fef8-44a9-963c-e7f79fcf227d',
        name: 'UNSUPPORTED_PASS',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: [],
      },
    ],
  },
  user_with_queued_pass: {
    hasQueuedPass: true,
    parentalPin: {
      parentalPinRequired: false,
    },
    entitlements: [
      {
        id: 'b8aa9e3b-a8c7-4ae8-be63-c5815c8d7aa3',
        name: 'SPORTS',
        productId: 'C_002014',
        productStaticId: 'SPORTS_DAY_PASS',
        state: 'QUEUED',
        startDate: '2017-10-30T10:43:45Z',
        endDate: '2037-01-17T16:43:45Z',
        billingType: 'Non_Recurring',
        contentSegments: ['SPORTS'],
      },
    ],
  },
  user_with_pass_offers: {
    entitlements: [
      {
        id: '8e5623b2-fef8-44a9-963c-e7f79fcf227d',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
      {
        id: '8e5623b2-fef8-44a9-963c-e7f79fcf227e',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
      {
        id: '8e5623b2-fef8-44a9-963c-e7f79fcf227f',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
      {
        id: '08a3191b-6238-4bac-b3d3-411fa90b0dcd',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-02-08T15:15:05Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
      {
        id: '08a3191b-6238-4bac-b3d3-411fa90b0dce',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-02-08T15:15:05Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
    ],
    subscriptions: [
      {
        id: '99aa4a4b-8b03-4632-8636-525d66e8b79d',
        startDate: '2016-10-31T15:53:54Z',
        state: 'ACTIVE',
        lastRenewalDate: '2017-01-14T10:21:08Z',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2017-02-14T15:53:54Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
            startDate: '2016-11-14T15:53:54Z',
          },
        },
        entitlements: ['8e5623b2-fef8-44a9-963c-e7f79fcf227d'],
        allowedOperations: [
          'AGENT_CANCEL',
          'UPDATE_PRODUCT',
          'DELETE',
          'SYSTEM_CANCEL',
          'USER_CANCEL',
          'IMMEDIATE_CANCEL',
        ],
      },
      {
        id: '99aa4a4b-8b03-4632-8636-525d66e8b79e',
        startDate: '2016-10-31T15:53:54Z',
        state: 'ACTIVE',
        lastRenewalDate: '2017-01-14T10:21:08Z',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2017-02-14T15:53:54Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
            startDate: '2016-11-14T15:53:54Z',
          },
        },
        entitlements: ['8e5623b2-fef8-44a9-963c-e7f79fcf227e'],
        allowedOperations: [
          'AGENT_CANCEL',
          'UPDATE_PRODUCT',
          'DELETE',
          'SYSTEM_CANCEL',
          'USER_CANCEL',
          'IMMEDIATE_CANCEL',
        ],
      },
      {
        id: '99aa4a4b-8b03-4632-8636-525d66e8b79f',
        startDate: '2016-10-31T15:53:54Z',
        state: 'USER_CANCELLED',
        lastRenewalDate: '2017-01-14T10:21:08Z',
        cancellationEffectiveDate: '2026-08-29T13:27:18Z',
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
            startDate: '2016-11-14T15:53:54Z',
          },
        },
        entitlements: ['8e5623b2-fef8-44a9-963c-e7f79fcf227f'],
        allowedOperations: ['REINSTATE', 'DELETE'],
      },
      {
        id: '40f530ed-0139-4bf7-a5e1-3355d51648d8',
        startDate: '2017-02-08T15:15:05Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2027-04-08T15:15:05Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2017-02-08T15:15:05Z',
            endDate: '2027-04-08T15:15:05Z',
          },
        },
        entitlements: ['08a3191b-6238-4bac-b3d3-411fa90b0dcd'],
        allowedOperations: [
          'AGENT_CANCEL',
          'UPDATE_PRODUCT',
          'DELETE',
          'SYSTEM_CANCEL',
          'USER_CANCEL',
          'IMMEDIATE_CANCEL',
        ],
      },
      {
        id: '40f530ed-0139-4bf7-a5e1-3355d51648d9',
        startDate: '2017-02-08T15:15:05Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2037-04-08T15:15:05Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2017-02-08T15:15:05Z',
            endDate: '2037-04-08T15:15:05Z',
          },
        },
        entitlements: ['08a3191b-6238-4bac-b3d3-411fa90b0dce'],
        allowedOperations: [
          'AGENT_CANCEL',
          'UPDATE_PRODUCT',
          'DELETE',
          'SYSTEM_CANCEL',
          'USER_CANCEL',
          'IMMEDIATE_CANCEL',
        ],
      },
    ],
  },
  user_with_pass_offers_and_no_cancellation_offers: {
    ineligibleForCancellationOffer: true,
    entitlements: [
      {
        id: '08a3191b-6238-4bac-b3d3-411fa90b0dcd',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-02-08T15:15:05Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
    ],
    subscriptions: [
      {
        id: '40f530ed-0139-4bf7-a5e1-3355d51648d8',
        startDate: '2017-02-08T15:15:05Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2027-04-08T15:15:05Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2017-02-08T15:15:05Z',
            endDate: '2027-04-08T15:15:05Z',
          },
        },
        entitlements: ['08a3191b-6238-4bac-b3d3-411fa90b0dcd'],
        allowedOperations: [
          'AGENT_CANCEL',
          'UPDATE_PRODUCT',
          'DELETE',
          'SYSTEM_CANCEL',
          'USER_CANCEL',
          'IMMEDIATE_CANCEL',
        ],
      },
    ],
  },
  user_with_no_cancellation_offer: {
    ineligibleForCancellationOffer: true,
  },
  user_with_no_continue_watching_data: {
    parentalPin: {
      parentalPinRequired: false,
    },
    noContinueWatchingData: true,
  },
  user_to_have_new_address: {
    accountDetailsOneDeliveryAddress: true,
    paymentPin: {
      pinRequired: false,
    },
  },
  user_to_edit_address: {
    accountDetailsOneDeliveryAddress: true,
    paymentPin: {
      pinRequired: false,
    },
  },
  user_no_account_to_have_new_address: {
    noAccountDetails: true,
    paymentPin: {
      pinRequired: false,
    },
  },
  user_with_empty_recs: {},
  user_with_default_recs_profile: {},
  user_with_default_recs_profile_and_assets: {},
  'xuvokuv@email.com': {
    fullySignedUp: false,
    noPaymentAccount: true,
    noAccountDetails: true,
    entitlements: undefined,
  },
  'partial_submit@email.com': {
    fullySignedUp: false,
    noPaymentAccount: true,
    noAccountDetails: true,
    entitlements: undefined,
  },
  'quefomij@email.com': {
    fullySignedUp: false,
    noPaymentAccount: true,
    entitlements: undefined,
    parentalPin: {
      pin: '1234',
    },
  },
  'dofyweb@email.com': {
    fullySignedUp: false,
    noPaymentAccount: true,
    differentDeliveryAddressOnAccount: true,
    entitlements: undefined,
  },
  'johncenaaa@sky.uk': {
    password: 'aaaaaaaa',
  },
  'a1257mseltualhu@sky.uk': {},
  'a4500vcbeitsytu@sky.uk': {
    entitlements: [
      {
        id: '8e5623b2-fef8-44a9-963c-e7f79fcf227d',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
  },
  'a1519916895454@testmail.com': {
    entitlements: [
      {
        id: 'b9ed2570-6e63-11e5-9d70-feff819cdc9f',
        name: 'SPORTS',
        productId: 'C_002014',
        productStaticId: 'SPORTS_DAY_PASS',
        state: 'ACTIVATED',
        entitlementDuration: 'P1D',
        startDate: '2016-07-29T00:00:00Z',
        contentSegments: ['SPORTS'],
        endDate: '2016-07-29T23:59:59Z',
        billingType: 'Non_Recurring',
      },
    ],
  },
  keepMeSignedInOnlyUser: {
    entitlements: undefined,
    subscriptions: [],
  },
  user_no_delivery_address: {
    noDeliveryAddressOnAccount: true,
    entitlements: undefined,
  },
  user_no_addresses: {
    noAddressesOnAccount: true,
    entitlements: undefined,
  },
  user_no_account_in_account_manager: {
    paymentPin: {
      pinRequired: false,
    },
    noAccountDetails: true,
    entitlements: undefined,
  },
  user_with_hd_pass: {
    entitlements: [
      {
        id: '12567cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'HD',
        productId: 'C_006602',
        productStaticId: 'HD_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2017-05-11T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['HD'],
      },
      {
        id: '9bb1d400-6da2-11e5-9d70-feff819cdc9f',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['MOVIES'],
      },
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc91',
        name: 'KIDS',
        productId: 'C_003116',
        productStaticId: 'KIDS_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['KIDS'],
      },
      {
        id: '71231cd0-6da2-11e5-9d70-feff819cdc9f',
        name: 'ENTERTAINMENT',
        productId: 'C_002009',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2016-07-29T13:27:18Z',
        billingType: 'Recurring',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2017-05-11T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2017-08-11T13:27:18Z',
        product: {
          id: 'C_006602',
          staticId: 'HD',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2017-05-11T13:27:18Z',
            endDate: '2017-08-11T13:27:18Z',
            offers: [],
          },
        },
        entitlements: ['12567cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
    ],
    parentalPin: {
      parentalPinRequired: false,
    },
  },
  user_invalid_address_value: {
    invalidAddressFieldOnAccount: true,
  },
  user_missing_address_value: {
    missingAddressFieldOnAccount: true,
  },
  user_with_ineligible_vouchers: {
    subscriptions: [
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2016-08-29T13:27:18Z',
        offerAllowed: false,
        product: {
          id: 'C_002009',
          staticId: 'ENTERTAINMENT_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af0',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '31.99',
        nextRenewalDueDate: '2030-08-29T13:27:18Z',
        offerAllowed: true,
        product: {
          id: 'C_002009',
          staticId: 'SPORTS_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
            offers: [],
          },
        },
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc9f'],
        allowedOperations: ['AGENT_CANCEL', 'APPLY_OFFER', 'DELETE', 'SYSTEM_CANCEL', 'USER_CANCEL'],
      },
      {
        id: '18c4ce82-6e12-435d-9151-221efeb12af1',
        startDate: '2016-07-29T13:27:18Z',
        state: 'ACTIVE',
        nextRenewalAmount: '7.00',
        cancellationEffectiveDate: '2016-08-29T13:27:18Z',
        product: {
          id: 'C_003116',
          staticId: 'KIDS_SUBSCRIPTION',
          context: {
            subscriptionType: 'MONTHLY',
          },
        },
        offers: [],
        entitlements: ['71231cd0-6da2-11e5-9d70-feff819cdc91'],
        allowedOperations: ['REINSTATE', 'DELETE'],
      },
    ],
  },
  user_with_credit: {
    creditBalancePrePurchase: '50.00',
    entitlements: undefined,
    subscriptions: [],
    paymentPin: {
      errorCode: 'COM_00005',
      description: 'Not Found: <data item>',
    },
  },
  user_with_credit_and_trials_used: {
    creditBalancePrePurchase: '50.00',
    entitlements: undefined,
    subscriptions: [],
    paymentPin: {
      errorCode: 'COM_00005',
      description: 'Not Found: <data item>',
    },
  },
  user_with_partner_pass: {
    entitlements: [
      {
        id: '08a3191b-6238-4bac-b3d3-411fa90b0dcd',
        name: 'MOVIES',
        productId: 'C_002002',
        productStaticId: 'CINEMA_SUBSCRIPTION',
        state: 'ACTIVATED',
        contentSegments: ['MOVIES'],
        startDate: '2017-02-08T15:15:05Z',
        billingType: 'Recurring',
      },
      {
        id: 'n/a',
        name: 'PARTNER_ENTERTAINMENT',
        productStaticId: 'ENTERTAINMENT_SUBSCRIPTION',
        state: 'ACTIVATED',
        startDate: '2019-05-15T14:41:14Z',
        billingType: 'Recurring',
        sourcePartner: 'VODAFONE',
        contentSegments: ['ENTERTAINMENT'],
      },
    ],
    subscriptions: [
      {
        id: '40f530ed-0139-4bf7-a5e1-3355d51648d8',
        startDate: '2017-02-08T15:15:05Z',
        state: 'ACTIVE',
        nextRenewalAmount: '15.00',
        nextRenewalDueDate: '2027-04-08T15:15:05Z',
        product: {
          id: 'C_002002',
          staticId: 'CINEMA_SUBSCRIPTION',
          context: {
            subscriptionType: 'UPFRONT_PAID',
            startDate: '2017-02-08T15:15:05Z',
            endDate: '2027-04-08T15:15:05Z',
          },
        },
        entitlements: ['08a3191b-6238-4bac-b3d3-411fa90b0dcd'],
        allowedOperations: [
          'AGENT_CANCEL',
          'UPDATE_PRODUCT',
          'DELETE',
          'SYSTEM_CANCEL',
          'USER_CANCEL',
          'IMMEDIATE_CANCEL',
        ],
      },
    ],
  },
};

module.exports = Object.keys(users).reduce((acc, key) => {
  acc[key] = Object.assign(
    {
      username: key,
      userToken: key,
      skyIdToken: `01-${key}`,
      password: userDefaults.password,
      entitlements: userDefaults.entitlements.slice(0),
      subscriptions: userDefaults.subscriptions.slice(0),
      parentalPin: userDefaults.parentalPin,
      paymentPin: userDefaults.paymentPin,
      paymentAccounts: userDefaults.paymentAccounts,
      devices: userDefaults.devices,
      registrations: userDefaults.registrations,
      getProfile: getProfileFixture(key),
      fullySignedUp: userDefaults.fullySignedUp,
      trialsUsed: userDefaults.trialsUsed,
      creditBalancePrePurchase: userDefaults.creditBalancePrePurchase,
    },
    users[key]
  );

  return acc;
}, {});
