const supertest = require('supertest');
const sinon = require('sinon');

const app = require('../app');
const threeDSecureResponse = require('../routes/commerce/commerce/sales/purchase-basket/3d-secure-required.json');

describe('3D Secure', () => {
  let clock;
  let server;

  beforeAll(() => {
    clock = sinon.useFakeTimers(1457621019000);
    server = app.listen();
  });

  afterAll(() => {
    clock.restore();
    server.close();
  });

  function postRequest(url) {
    return supertest(server)
      .post(url)
      .set('content-type', 'application/vnd.charges.v1+json')
      .set('x-skyott-language', 'en');
  }

  const headers = {
    'X-SkyOTT-Device': 'COMPUTER',
    'X-SkyOTT-Platform': 'PC',
    'X-SkyOTT-Territory': 'IE',
    'X-SkyOTT-Proposition': 'NOWTV',
    'X-SkyOTT-Provider': 'NOWTV',
    'X-SkyOTT-UserToken': '1234567',
    'Content-Type': 'application/vnd.charges.v1+json',
    'X-SCENARIO': '3d_secure',
  };

  it('should return a successful response when creating a price for the basket', () => {
    return postRequest('/commerce/bridge/order')
      .set(headers)
      .set({ 'Content-MD5': '37d383e1d3cf504d8f07f85231248978' })
      .send({ payment: {}, products: [{ id: 'C_008008', quantity: 1 }] })
      .expect(200)
      .expect(res => expect(res.body).toEqual(threeDSecureResponse));
  });
});
