'use strict';

const supertest = require('supertest');

const app = require('../app');

describe('Error interceptor', () => {
  const testCases = {
    errSignin: '/signin/service/international',
    errSignup: '/signup/service/international',
  };
  let server;

  beforeAll(() => {
    server = app.listen();
  });

  afterAll(() => {
    server.close();
  });

  Object.keys(testCases).forEach(key => {
    it(`should return 500 if ${key} set on url ${testCases[key]}`, () => {
      return supertest(server)
        .get(testCases[key])
        .set({ Cookie: `${key}=true` })
        .expect(500);
    });
  });

  it("should not return 500 if cookie doesn't match", () => {
    return supertest(server)
      .get('/signin/service/international')
      .set({ Cookie: 'dummyCookie=true' })
      .expect(400);
  });
});
