'use strict';

const supertest = require('supertest');

const app = require('../app');

const CORRECT_HEADERS = {
  'X-SkyOTT-Language': 'en',
  'X-SkyOTT-Device': 'COMPUTER:PC',
  'X-SkyOTT-Territory': 'IE',
  'X-SkyOTT-Proposition': 'NOWTV',
};

const ONE_MISSING_HEADER = {
  'X-SkyOTT-Language': 'en',
  'X-SkyOTT-Device': 'COMPUTER:PC',
  'X-SkyOTT-Proposition': 'NOWTV',
};

describe('Labelling feed', () => {
  let server;

  beforeAll(() => {
    server = app.listen();
  });

  afterAll(() => {
    server.close();
  });

  describe('GET /v3/labels', () => {
    it('should return labels', () => {
      const expectedAllSectionsJson = require('../labelling-feed/web/mock.jc.en.json');

      return supertest(server)
        .get('/v3/labels')
        .set(CORRECT_HEADERS)
        .expect(200, expectedAllSectionsJson);
    });

    it('should return 400 if a header is missing', () => {
      return supertest(server)
        .get('/v3/labels')
        .set(ONE_MISSING_HEADER)
        .expect(400);
    });

    it('should return jc language if provided', () => {
      const expectedAllSectionsJson = require('../labelling-feed/web/mock.jc.jc.json');

      const JC_HEADERS = Object.assign({}, CORRECT_HEADERS, {
        'X-SkyOTT-Language': 'jc',
      });

      return supertest(server)
        .get('/v3/labels')
        .set(JC_HEADERS)
        .expect(200, expectedAllSectionsJson);
    });
  });
});
