'use strict';

const supertest = require('supertest');

const app = require('../app');

const IE_HEADERS = {
  'X-SkyOTT-Language': 'en',
  'X-SkyOTT-Device': 'COMPUTER',
  'X-SkyOTT-Territory': 'IE',
  'X-SkyOTT-Proposition': 'NOWTV',
};

const ONE_MISSING_HEADER = {
  'X-SkyOTT-Language': 'en',
  'X-SkyOTT-Device': 'COMPUTER',
  'X-SkyOTT-Proposition': 'NOWTV',
};

const BREAK_CMS_MENU_HEADER = {
  'X-SkyOTT-Language': 'breakCmsMenu',
  'X-SkyOTT-Device': 'COMPUTER',
  'X-SkyOTT-Territory': 'IE',
  'X-SkyOTT-Proposition': 'NOWTV',
};

const ES_HEADERS = {
  'X-SkyOTT-Language': 'es',
  'X-SkyOTT-Device': 'COMPUTER',
  'X-SkyOTT-Territory': 'ES',
  'X-SkyOTT-Proposition': 'NOWTV',
};

describe('Menu feed', () => {
  let server;

  beforeAll(() => {
    server = app.listen();
  });

  afterAll(() => {
    server.close();
  });

  describe('GET /v3/query/menu', () => {
    it('should return 200', () => {
      const expectedMenuJson = require('../routes/pcms/menu/menu-nowtv-ie-en');

      return supertest(server)
        .get('/v3/query/menu')
        .set(IE_HEADERS)
        .expect(200, expectedMenuJson);
    });

    it('should return 400 if a header is missing', () => {
      return supertest(server)
        .get('/v3/query/menu')
        .set(ONE_MISSING_HEADER)
        .expect(400);
    });

    it('should return 500 if language is `breakCmsMenu`', () => {
      return supertest(server)
        .get('/v3/query/menu')
        .set(BREAK_CMS_MENU_HEADER)
        .expect(500);
    });

    it('should return spanish menu if territory is ES', () => {
      const expectedMenuJson = require('../routes/pcms/menu/menu-nowtv-es-es');

      return supertest(server)
        .get('/v3/query/menu')
        .set(ES_HEADERS)
        .expect(200, expectedMenuJson);
    });
  });
});
