'use strict';

const supertest = require('supertest');

const app = require('../app');

const GET_MVPD = '/mgs/mvpd';
const GET_MVPD_DATA = '/mgs/mvpdData';

describe('MVPD Gateway Service', () => {
  let server;

  beforeAll(() => {
    server = app.listen();
  });

  afterAll(() => {
    server.close();
  });

  describe('Get MVPD', () => {
    it('should return 200', () => {
      return supertest(server)
        .get(GET_MVPD)
        .expect(res => {
          expect(res.body.mvpd[0].name).toBe('Comcast');
        })
        .expect(200);
    });

    it('should return 200 and Verizon in first place', () => {
      return supertest(server)
        .get(GET_MVPD)
        .set('fake_ip_address', '1.2.3.4')
        .expect(res => {
          expect(res.body.mvpd[0].name).toBe('Verizon');
        })
        .expect(200);
    });

    it('should return 200 and HBA url', () => {
      return supertest(server)
        .get(GET_MVPD)
        .expect(res => {
          expect(res.body.hba).toBeDefined();
        })
        .expect(200);
    });

    it('should return 200 and no HBA url', () => {
      return supertest(server)
        .get(GET_MVPD)
        .query({ skipHba: true })
        .expect(res => {
          expect(res.body.hba).not.toBeDefined();
        })
        .expect(200);
    });
  });

  describe('Get MVPD data', () => {
    it('should return 200 and Comcast as MVPD', () => {
      return supertest(server)
        .get(GET_MVPD_DATA)
        .query({ mvpd: 'comcast' })
        .expect(res => {
          expect(res.body.name).toBe('Comcast');
        })
        .expect(200);
    });

    it('should return 200 and Verizon as MVPD', () => {
      return supertest(server)
        .get(GET_MVPD_DATA)
        .query({ mvpd: 'verizon' })
        .expect(res => {
          expect(res.body.name).toBe('Verizon');
        })
        .expect(200);
    });
  });
});
