const supertest = require('supertest');

const app = require('../app');

describe('Oogway', () => {
  let server;

  beforeAll(() => {
    server = app.listen();
  });

  afterAll(() => {
    server.close();
  });

  it('should return the public profile', () => {
    const publicProfile = require('../routes/oogway/oogway/profile');

    return supertest(server)
      .get('/oogway/public/profile')
      .set({ Cookie: 'skyCEsidtrk01=jLaJLYqzsHC22+0z52gyxA1JDp30JjLRuFrWNvZB/PM=' })
      .expect(JSON.parse(JSON.stringify(publicProfile).replace('__EMAIL__', 'valid_user@cena.com')));
  });

  it('should return a UK response based on the cookie', () => {
    const publicProfile = require('../routes/oogway/oogway/profile-uk');

    return supertest(server)
      .get('/oogway/public/profile')
      .set({ Cookie: 'skyCEsidismesso01=01-uk_user', 'X-SkyId-Token': 'Session 01-uk_user' })
      .expect(publicProfile);
  });

  it('should replace the username based on the cookie', () => {
    return supertest(server)
      .get('/oogway/public/profile')
      .set({ Cookie: 'skyOauth=01-falafel_user' })
      .expect(res => {
        expect(res.body.profile.details.username).toEqual('valid_user');
      });
  });
});
