'use strict';

const supertest = require('supertest');

const app = require('../app');

describe('Query API for static IDs', () => {
  let server;

  beforeAll(() => {
    server = app.listen();
  });

  afterAll(() => {
    server.close();
  });

  function getRequest(url) {
    return supertest(server)
      .get(url)
      .set('x-skyott-language', 'en')
      .set('x-skyott-proposition', 'MOCK')
      .set('x-skyott-territory', 'JC');
  }

  describe('GET /v3/query/node/static_id/:staticId', () => {
    it('should return a 200 for entertainment', () => {
      return getRequest('/v3/query/node/static_id/ENTERTAINMENT_SUBSCRIPTION').expect(200);
    });

    it('should return a 200 for cinema', () => {
      return getRequest('/v3/query/node/static_id/CINEMA_SUBSCRIPTION').expect(200);
    });

    it('should return a 200 for sports subscription', () => {
      return getRequest('/v3/query/node/static_id/SPORTS_SUBSCRIPTION').expect(200);
    });

    it('should return a 200 for sports week', () => {
      return getRequest('/v3/query/node/static_id/SPORTS_WEEK_PASS').expect(200);
    });

    it('should return a 200 for sports day', () => {
      return getRequest('/v3/query/node/static_id/SPORTS_DAY_PASS').expect(200);
    });

    it('should return a 404 for a static ID that does not exist', () => {
      return getRequest('/v3/query/node/static_id/NOTHING').expect(404);
    });
  });
});
