const supertest = require('supertest');
const sinon = require('sinon');

const app = require('../app');

describe('Sales', () => {
  let clock;
  let server;

  beforeAll(() => {
    clock = sinon.useFakeTimers(1457621019000);
    server = app.listen();
  });

  afterAll(() => {
    clock.restore();
    server.close();
  });

  function postRequest(url) {
    return supertest(server)
      .post(url)
      .set('content-type', 'application/vnd.charges.v1+json')
      .set('x-skyott-language', 'en');
  }

  const headers = {
    'X-SkyOTT-Device': 'COMPUTER',
    'X-SkyOTT-Platform': 'PC',
    'X-SkyOTT-Territory': 'IE',
    'X-SkyOTT-Proposition': 'NOWTV',
    'X-SkyOTT-Provider': 'NOWTV',
    'X-SkyOTT-UserToken': '1234567',
    'Content-Type': 'application/vnd.charges.v1+json',
  };

  describe('Price basket', () => {
    it('should return a successful response when creating a price for the basket', () => {
      return postRequest('/commerce/bridge/charges')
        .set(headers)
        .set({
          'Content-MD5': '09032214fa67bd7cc860dc4ec7c7658c',
        })
        .send({
          products: [
            {
              id: 'C_008008',
              quantity: 1,
            },
          ],
        })
        .expect(200);
    });

    it('should include offers if valid voucher code passed in', () => {
      return postRequest('/commerce/bridge/charges')
        .set(headers)
        .set({
          'Content-MD5': '330cbb641fb3e357d41fa59d6f552f1c',
        })
        .send({
          vouchers: ['MYSPORTSVOUCHER'],
        })
        .expect(200)
        .expect(res => {
          if (res.body.selection.offers.length !== 1) {
            throw new Error('offers should have length 1');
          }
        });
    });

    it('should return an error when creating a price for the basket with invalid content md5', () => {
      return postRequest('/commerce/bridge/charges')
        .set({ 'Content-MD5': 'INVALID' })
        .expect(403);
    });
  });
});
