const cloneDeep = require('lodash/cloneDeep');

const users = require('../routes/sky-id/sky-id/users');

function getUserWithCorrespondingUserToken(context) {
  const userToken = context.request.get('X-SkyOTT-UserToken');
  const skyIdToken = context.request.get('x-skyid-token').replace('01-', '');
  const authToken = (context.request.get('authorization') || '').slice(11); // ignore "NowTV-Auth " prefix
  const queryUserToken = context.request.query && context.request.query.userToken;
  const token = userToken || skyIdToken || authToken || queryUserToken;
  const validUsernames = Object.keys(users);

  return validUsernames.find(validUsername => users[validUsername].userToken === token) || 'valid_user';
}

function getUserWithCorrespondingSkyIdToken(context) {
  const skyIdToken = context.request.get('X-SkyId-Token').split(' ')[1];
  const validUsernames = Object.keys(users);

  return validUsernames.find(validUsername => users[validUsername].skyIdToken === skyIdToken) || 'valid_user';
}

function getDataForUserOrDefault(context) {
  const userToken = getUserWithCorrespondingUserToken(context) || 'valid_user';
  const dataToReturn = users[userToken] || users.valid_user;
  return Array.isArray(dataToReturn) ? dataToReturn.map(cloneDeep) : cloneDeep(dataToReturn);
}

function getDataItemForUserOrDefault(context, key) {
  const userToken = getUserWithCorrespondingUserToken(context) || 'valid_user';
  const userData = users[userToken] || users.valid_user;
  const dataToReturn = userData[key] || users.valid_user[key];
  return Array.isArray(dataToReturn) ? dataToReturn.map(cloneDeep) : cloneDeep(dataToReturn);
}

module.exports = {
  getUserWithCorrespondingUserToken,
  getUserWithCorrespondingSkyIdToken,
  getDataForUserOrDefault,
  getDataItemForUserOrDefault,
};
